@@ -30,7 +30,11 @@
 #include "core/gimpdatafactory.h"
 
 #include "widgets/gimpcontainerview.h"
+#include "widgets/gimpdataeditor.h"
 #include "widgets/gimpdatafactoryview.h"
+#include "widgets/gimpdialogfactory.h"
+
+#include "dialogs/dialogs.h"
 
 #include "actions.h"
 #include "data-commands.h"
@@ -38,27 +42,23 @@
 #include "gimp-intl.h"
 
 
-void
-data_edit_data_cmd_callback (GtkAction *action,
-			     gpointer   user_data)
+typedef struct _GimpDataDeleteData GimpDataDeleteData;
+
+struct _GimpDataDeleteData
 {
-  GimpDataFactoryView *view = GIMP_DATA_FACTORY_VIEW (user_data);
-  GimpContext         *context;
-  GimpData            *data;
+  GimpDataFactory *factory;
+  GimpData        *data;
+};
 
-  context = gimp_container_view_get_context (GIMP_CONTAINER_EDITOR (view)->view);
 
-  data = (GimpData *)
-    gimp_context_get_by_type (context,
-			      view->factory->container->children_type);
+/*  local function prototypes  */
 
-  if (view->data_edit_func && data &&
-      gimp_container_have (view->factory->container,
-			   GIMP_OBJECT (data)))
-    {
-      view->data_edit_func (data, GTK_WIDGET (view));
-    }
-}
+static void   data_delete_callback (GtkWidget *widget,
+                                    gboolean   delete,
+                                    gpointer   data);
+
+
+/*  public functions  */
 
 void
 data_new_data_cmd_callback (GtkAction *action,
@@ -119,35 +119,6 @@ data_duplicate_data_cmd_callback (GtkAction *action,
     }
 }
 
-typedef struct _GimpDataDeleteData GimpDataDeleteData;
-
-struct _GimpDataDeleteData
-{
-  GimpDataFactory *factory;
-  GimpData        *data;
-};
-
-static void
-data_delete_callback (GtkWidget *widget,
-                      gboolean   delete,
-                      gpointer   data)
-{
-  GimpDataDeleteData *delete_data = data;
-
-  if (delete)
-    {
-      GError *error = NULL;
-
-      if (! gimp_data_factory_data_delete (delete_data->factory,
-                                           delete_data->data,
-                                           TRUE, &error))
-        {
-          g_message (error->message);
-          g_clear_error (&error);
-        }
-    }
-}
-
 void
 data_delete_data_cmd_callback (GtkAction *action,
 			       gpointer   user_data)
@@ -206,3 +177,56 @@ data_refresh_data_cmd_callback (GtkAction *action,
   gimp_data_factory_data_save (view->factory);
   gimp_data_factory_data_init (view->factory, FALSE);
 }
+
+void
+data_edit_data_cmd_callback (GtkAction   *action,
+                             const gchar *value,
+			     gpointer     user_data)
+{
+  GimpDataFactoryView *view = GIMP_DATA_FACTORY_VIEW (user_data);
+  GimpContext         *context;
+  GimpData            *data;
+
+  context = gimp_container_view_get_context (GIMP_CONTAINER_EDITOR (view)->view);
+
+  data = (GimpData *)
+    gimp_context_get_by_type (context,
+			      view->factory->container->children_type);
+
+  if (data && gimp_container_have (view->factory->container,
+                                   GIMP_OBJECT (data)))
+    {
+      GdkScreen *screen = gtk_widget_get_screen (GTK_WIDGET (view));
+      GtkWidget *dockable;
+
+      dockable = gimp_dialog_factory_dialog_raise (global_dock_factory, screen,
+                                                   value, -1);
+
+      gimp_data_editor_set_data (GIMP_DATA_EDITOR (GTK_BIN (dockable)->child),
+                                 data);
+    }
+}
+
+
+/*  private functions  */
+
+static void
+data_delete_callback (GtkWidget *widget,
+                      gboolean   delete,
+                      gpointer   data)
+{
+  GimpDataDeleteData *delete_data = data;
+
+  if (delete)
+    {
+      GError *error = NULL;
+
+      if (! gimp_data_factory_data_delete (delete_data->factory,
+                                           delete_data->data,
+                                           TRUE, &error))
+        {
+          g_message (error->message);
+          g_clear_error (&error);
+        }
+    }
+}
