@@ -45,8 +45,6 @@
 
 /*  local function prototypes  */
 
-static void   edit_actions_buffer_changed     (Gimp            *gimp,
-                                               GimpActionGroup *group);
 static void   edit_actions_foreground_changed (GimpContext     *context,
                                                const GimpRGB   *color,
                                                GimpActionGroup *group);
@@ -77,7 +75,7 @@ static GimpActionEntry edit_actions[] =
 
   { "edit-undo-clear", GTK_STOCK_CLEAR,
     N_("_Clear Undo History"), "",
-    N_("Clear undo history"),
+    N_("Clear undo history..."),
     G_CALLBACK (edit_undo_clear_cmd_callback),
     GIMP_HELP_EDIT_UNDO_CLEAR },
 
@@ -162,11 +160,6 @@ edit_actions_setup (GimpActionGroup *group)
                                       G_N_ELEMENTS (edit_fill_actions),
                                       G_CALLBACK (edit_fill_cmd_callback));
 
-  g_signal_connect_object (group->gimp, "buffer_changed",
-                           G_CALLBACK (edit_actions_buffer_changed),
-                           group, 0);
-  edit_actions_buffer_changed (group->gimp, group);
-
   g_signal_connect_object (context, "foreground_changed",
                            G_CALLBACK (edit_actions_foreground_changed),
                            group, 0);
@@ -191,14 +184,12 @@ void
 edit_actions_update (GimpActionGroup *group,
                      gpointer         data)
 {
-  GimpImage    *gimage;
+  GimpImage    *gimage       = action_data_get_image (data);
   GimpDrawable *drawable     = NULL;
   gchar        *undo_name    = NULL;
   gchar        *redo_name    = NULL;
   gboolean      undo_enabled = FALSE;
 
-  gimage = action_data_get_image (data);
-
   if (gimage)
     {
       GimpUndo *undo;
@@ -225,6 +216,7 @@ edit_actions_update (GimpActionGroup *group,
         }
     }
 
+
 #define SET_LABEL(action,label) \
         gimp_action_group_set_action_label (group, action, (label))
 #define SET_SENSITIVE(action,condition) \
@@ -240,14 +232,14 @@ edit_actions_update (GimpActionGroup *group,
   g_free (undo_name);
   g_free (redo_name);
 
-  SET_SENSITIVE ("edit-cut",        drawable);
-  SET_SENSITIVE ("edit-copy",       drawable);
-  SET_SENSITIVE ("edit-paste",      gimage && group->gimp->global_buffer);
-  SET_SENSITIVE ("edit-paste-into", gimage && group->gimp->global_buffer);
+  SET_SENSITIVE ("edit-cut",          drawable);
+  SET_SENSITIVE ("edit-copy",         drawable);
+  SET_SENSITIVE ("edit-paste",        gimage);
+  SET_SENSITIVE ("edit-paste-into",   gimage);
 
-  SET_SENSITIVE ("edit-named-cut",   drawable);
-  SET_SENSITIVE ("edit-named-copy",  drawable);
-  SET_SENSITIVE ("edit-named-paste", drawable);
+  SET_SENSITIVE ("edit-named-cut",    drawable);
+  SET_SENSITIVE ("edit-named-copy",   drawable);
+  SET_SENSITIVE ("edit-named-paste",  gimage);
 
   SET_SENSITIVE ("edit-clear",        drawable);
   SET_SENSITIVE ("edit-fill-fg",      drawable);
@@ -261,17 +253,6 @@ edit_actions_update (GimpActionGroup *group,
 
 /*  private functions  */
 
-static void
-edit_actions_buffer_changed (Gimp            *gimp,
-                             GimpActionGroup *group)
-{
-  gboolean buf = (gimp->global_buffer != NULL);
-
-  gimp_action_group_set_action_sensitive (group, "edit-paste",        buf);
-  gimp_action_group_set_action_sensitive (group, "edit-paste-into",   buf);
-  gimp_action_group_set_action_sensitive (group, "edit-paste-as-new", buf);
-}
-
 static void
 edit_actions_foreground_changed (GimpContext     *context,
                                  const GimpRGB   *color,
