@@ -58,16 +58,12 @@ static void   file_actions_last_opened_reorder (GimpContainer   *container,
 
 static GimpActionEntry file_actions[] =
 {
-  { "file-menu", NULL, N_("_File") },
-
-  { "file-open-recent-menu", NULL,
-    N_("Open _Recent"), "", NULL },
-
-  { "file-acquire-menu", NULL,
-    N_("_Acquire"), NULL, NULL },
+  { "file-menu",             NULL, N_("_File")        },
+  { "file-open-recent-menu", NULL, N_("Open _Recent") },
+  { "file-acquire-menu",     NULL, N_("_Acquire")     },
 
   { "file-open", GTK_STOCK_OPEN,
-    N_("_Open..."), "<control>O", NULL,
+    N_("_Open..."), NULL, NULL,
     G_CALLBACK (file_open_cmd_callback),
     GIMP_HELP_FILE_OPEN },
 
@@ -76,8 +72,13 @@ static GimpActionEntry file_actions[] =
     G_CALLBACK (file_open_from_image_cmd_callback),
     GIMP_HELP_FILE_OPEN },
 
+  { "file-open-as-layer", GIMP_STOCK_LAYER,
+    N_("Op_en as Layer..."), "<control><alt>O", NULL,
+    G_CALLBACK (file_open_as_layer_cmd_callback),
+    GIMP_HELP_FILE_OPEN_AS_LAYER },
+
   { "file-open-location", GIMP_STOCK_WEB,
-    N_("_Open Location..."), NULL, NULL,
+    N_("Open _Location..."), NULL, NULL,
     G_CALLBACK (file_open_location_cmd_callback),
     GIMP_HELP_FILE_OPEN_LOCATION },
 
@@ -199,6 +200,7 @@ file_actions_update (GimpActionGroup *group,
 #define SET_SENSITIVE(action,condition) \
         gimp_action_group_set_action_sensitive (group, action, (condition) != 0)
 
+  SET_SENSITIVE ("file-open-as-layer",    gimage);
   SET_SENSITIVE ("file-save",             gimage && drawable);
   SET_SENSITIVE ("file-save-as",          gimage && drawable);
   SET_SENSITIVE ("file-save-a-copy",      gimage && drawable);
