@@ -40,8 +40,8 @@
 #include "widgets/gimptemplateview.h"
 #include "widgets/gimpviewabledialog.h"
 
-#include "gui/dialogs.h"
-#include "gui/file-new-dialog.h"
+#include "dialogs/dialogs.h"
+#include "dialogs/image-new-dialog.h"
 
 #include "templates-commands.h"
 
@@ -66,7 +66,7 @@ templates_create_image_cmd_callback (GtkAction *action,
 
   if (template && gimp_container_have (container, GIMP_OBJECT (template)))
     {
-      templates_file_new_dialog (context->gimp, template, GTK_WIDGET (editor));
+      templates_image_new_dialog (context->gimp, template, GTK_WIDGET (editor));
     }
 }
 
@@ -359,19 +359,19 @@ templates_edit_template_dialog (Gimp         *gimp,
 }
 
 void
-templates_file_new_dialog (Gimp         *gimp,
-                           GimpTemplate *template,
-                           GtkWidget    *parent)
+templates_image_new_dialog (Gimp         *gimp,
+                            GimpTemplate *template,
+                            GtkWidget    *parent)
 {
   GtkWidget *dialog;
 
   dialog = gimp_dialog_factory_dialog_new (global_dialog_factory,
                                            gtk_widget_get_screen (parent),
-                                           "gimp-file-new-dialog", -1, FALSE);
+                                           "gimp-image-new-dialog", -1, FALSE);
 
   if (dialog)
     {
-      file_new_dialog_set (dialog, NULL, template);
+      image_new_dialog_set (dialog, NULL, template);
 
       gtk_window_present (GTK_WINDOW (dialog));
     }
