@@ -40,6 +40,14 @@ void   view_zoom_other_cmd_callback            (GtkAction *action,
                                                 gpointer   data);
 void   view_dot_for_dot_cmd_callback           (GtkAction *action,
                                                 gpointer   data);
+
+void   view_scroll_horizontal_cmd_callback     (GtkAction *action,
+                                                gint       value,
+                                                gpointer   data);
+void   view_scroll_vertical_cmd_callback       (GtkAction *action,
+                                                gint       value,
+                                                gpointer   data);
+
 void   view_info_window_cmd_callback           (GtkAction *action,
                                                 gpointer   data);
 void   view_navigation_window_cmd_callback     (GtkAction *action,
