@@ -20,7 +20,7 @@
 
 /*
  * This file is supposed to contain the generic (read: C) implementation
- * of the pixelfiddeling paint-functions.
+ * of the pixel fiddling paint-functions.
  */
 
 #include "config.h"
@@ -47,14 +47,14 @@
 /* This version of INT_MULT3 is very fast, but suffers from some
    slight roundoff errors.  It returns the correct result 99.987
    percent of the time */
-#define INT_MULT3(a,b,c,t)  ((t) = (a) * (b) * (c)+ 0x7F5B, ((((t) >> 7) + (t)) >> 16))
+#define INT_MULT3(a,b,c,t)  ((t) = (a) * (b) * (c) + 0x7F5B, ((((t) >> 7) + (t)) >> 16))
 /*
   This version of INT_MULT3 always gives the correct result, but runs at
   approximatly one third the speed. */
-/*  #define INT_MULT3(a,b,c,t) (((a) * (b) * (c)+ 32512) / 65025.0)
+/*  #define INT_MULT3(a,b,c,t) (((a) * (b) * (c) + 32512) / 65025.0)
  */
 
-#define INT_BLEND(a,b,alpha,tmp)  (INT_MULT((a)-(b), alpha, tmp) + (b))
+#define INT_BLEND(a,b,alpha,tmp)  (INT_MULT((a) - (b), alpha, tmp) + (b))
 
 #define RANDOM_TABLE_SIZE  4096
 
@@ -377,36 +377,40 @@ gimp_composite_hue_any_any_any_generic (GimpCompositeContext * ctx)
   guint r1, g1, b1;
   guint r2, g2, b2;
 
-  /*  assumes inputs are only 4 byte RGBA pixels  */
-  while (length--)
-    {
-      r1 = src1[0];
-      g1 = src1[1];
-      b1 = src1[2];
-      r2 = src2[0];
-      g2 = src2[1];
-      b2 = src2[2];
-      gimp_rgb_to_hsv_int(&r1, &g1, &b1);
-      gimp_rgb_to_hsv_int(&r2, &g2, &b2);
+  if (bytes1 > 2) {
+    /*  assumes inputs are only 4 byte RGBA pixels  */
+    while (length--)
+      {
+        r1 = src1[0];
+        g1 = src1[1];
+        b1 = src1[2];
+        r2 = src2[0];
+        g2 = src2[1];
+        b2 = src2[2];
+        gimp_rgb_to_hsv_int(&r1, &g1, &b1);
+        gimp_rgb_to_hsv_int(&r2, &g2, &b2);
 
-      r1 = r2;
+        r1 = r2;
 
-      /*  set the destination  */
-      gimp_hsv_to_rgb_int(&r1, &g1, &b1);
+        /*  set the destination  */
+        gimp_hsv_to_rgb_int(&r1, &g1, &b1);
 
-      dest[0] = r1;
-      dest[1] = g1;
-      dest[2] = b1;
+        dest[0] = r1;
+        dest[1] = g1;
+        dest[2] = b1;
 
-      if (has_alpha1 && has_alpha2)
-        dest[3] = MIN(src1[3], src2[3]);
-      else if (has_alpha2)
-        dest[3] = src2[3];
+        if (has_alpha1 && has_alpha2)
+          dest[3] = MIN(src1[3], src2[3]);
+        else if (has_alpha2)
+          dest[3] = src2[3];
 
-      src1 += bytes1;
-      src2 += bytes2;
-      dest += bytes2;
-    }
+        src1 += bytes1;
+        src2 += bytes2;
+        dest += bytes2;
+      }
+  } else {
+    ctx->D = ctx->B;
+  }
 }
 
 
@@ -432,36 +436,40 @@ gimp_composite_saturation_any_any_any_generic (GimpCompositeContext * ctx)
   guint r1, g1, b1;
   guint r2, g2, b2;
 
-  /*  assumes inputs are only 4 byte RGBA pixels  */
-  while (length--)
-    {
-      r1 = src1[0];
-      g1 = src1[1];
-      b1 = src1[2];
-      r2 = src2[0];
-      g2 = src2[1];
-      b2 = src2[2];
-      gimp_rgb_to_hsv_int(&r1, &g1, &b1);
-      gimp_rgb_to_hsv_int(&r2, &g2, &b2);
+  if (bytes1 > 2) {
+    /*  assumes inputs are only 4 byte RGBA pixels  */
+    while (length--)
+      {
+        r1 = src1[0];
+        g1 = src1[1];
+        b1 = src1[2];
+        r2 = src2[0];
+        g2 = src2[1];
+        b2 = src2[2];
+        gimp_rgb_to_hsv_int(&r1, &g1, &b1);
+        gimp_rgb_to_hsv_int(&r2, &g2, &b2);
 
-      g1 = g2;
+        g1 = g2;
 
-      /*  set the destination  */
-      gimp_hsv_to_rgb_int(&r1, &g1, &b1);
+        /*  set the destination  */
+        gimp_hsv_to_rgb_int(&r1, &g1, &b1);
 
-      dest[0] = r1;
-      dest[1] = g1;
-      dest[2] = b1;
+        dest[0] = r1;
+        dest[1] = g1;
+        dest[2] = b1;
 
-      if (has_alpha1 && has_alpha2)
-        dest[3] = MIN(src1[3], src2[3]);
-      else if (has_alpha2)
-        dest[3] = src2[3];
+        if (has_alpha1 && has_alpha2)
+          dest[3] = MIN(src1[3], src2[3]);
+        else if (has_alpha2)
+          dest[3] = src2[3];
 
-      src1 += bytes1;
-      src2 += bytes2;
-      dest += bytes2;
-    }
+        src1 += bytes1;
+        src2 += bytes2;
+        dest += bytes2;
+      }
+  } else {
+    ctx->D = ctx->B;
+  }
 }
 
 
@@ -487,36 +495,41 @@ gimp_composite_value_any_any_any_generic (GimpCompositeContext * ctx)
   guint r1, g1, b1;
   guint r2, g2, b2;
 
-  /*  assumes inputs are only 4 byte RGBA pixels  */
-  while (length--)
-    {
-      r1 = src1[0];
-      g1 = src1[1];
-      b1 = src1[2];
-      r2 = src2[0];
-      g2 = src2[1];
-      b2 = src2[2];
-      gimp_rgb_to_hsv_int(&r1, &g1, &b1);
-      gimp_rgb_to_hsv_int(&r2, &g2, &b2);
+  if (bytes1 > 2) {
+    /*  assumes inputs are only 4 byte RGBA pixels  */
+    /*  assumes inputs are only 4 byte RGBA pixels  */
+    while (length--)
+      {
+        r1 = src1[0];
+        g1 = src1[1];
+        b1 = src1[2];
+        r2 = src2[0];
+        g2 = src2[1];
+        b2 = src2[2];
+        gimp_rgb_to_hsv_int(&r1, &g1, &b1);
+        gimp_rgb_to_hsv_int(&r2, &g2, &b2);
 
-      b1 = b2;
+        b1 = b2;
 
-      /*  set the destination  */
-      gimp_hsv_to_rgb_int(&r1, &g1, &b1);
+        /*  set the destination  */
+        gimp_hsv_to_rgb_int(&r1, &g1, &b1);
 
-      dest[0] = r1;
-      dest[1] = g1;
-      dest[2] = b1;
+        dest[0] = r1;
+        dest[1] = g1;
+        dest[2] = b1;
 
-      if (has_alpha1 && has_alpha2)
-        dest[3] = MIN(src1[3], src2[3]);
-      else if (has_alpha2)
-        dest[3] = src2[3];
+        if (has_alpha1 && has_alpha2)
+          dest[3] = MIN(src1[3], src2[3]);
+        else if (has_alpha2)
+          dest[3] = src2[3];
 
-      src1 += bytes1;
-      src2 += bytes2;
-      dest += bytes2;
-    }
+        src1 += bytes1;
+        src2 += bytes2;
+        dest += bytes2;
+      }
+  } else {
+    ctx->D = ctx->B;
+  }
 }
 
 
@@ -542,38 +555,42 @@ gimp_composite_color_only_any_any_any_generic (GimpCompositeContext * ctx)
   guint r1, g1, b1;
   guint r2, g2, b2;
 
-  /*  assumes inputs are only 4 byte RGBA pixels  */
-  while (length--)
-    {
-      r1 = src1[0];
-      g1 = src1[1];
-      b1 = src1[2];
-      r2 = src2[0];
-      g2 = src2[1];
-      b2 = src2[2];
-      gimp_rgb_to_hsl_int(&r1, &g1, &b1);
-      gimp_rgb_to_hsl_int(&r2, &g2, &b2);
+  if (bytes1 > 2) {
+    /*  assumes inputs are only 4 byte RGBA pixels  */
+    while (length--)
+      {
+        r1 = src1[0];
+        g1 = src1[1];
+        b1 = src1[2];
+        r2 = src2[0];
+        g2 = src2[1];
+        b2 = src2[2];
+        gimp_rgb_to_hsl_int(&r1, &g1, &b1);
+        gimp_rgb_to_hsl_int(&r2, &g2, &b2);
 
-      /*  transfer hue and saturation to the source pixel  */
-      r1 = r2;
-      g1 = g2;
+        /*  transfer hue and saturation to the source pixel  */
+        r1 = r2;
+        g1 = g2;
 
-      /*  set the destination  */
-      gimp_hsl_to_rgb_int(&r1, &g1, &b1);
+        /*  set the destination  */
+        gimp_hsl_to_rgb_int(&r1, &g1, &b1);
 
-      dest[0] = r1;
-      dest[1] = g1;
-      dest[2] = b1;
+        dest[0] = r1;
+        dest[1] = g1;
+        dest[2] = b1;
 
-      if (has_alpha1 && has_alpha2)
-        dest[3] = MIN(src1[3], src2[3]);
-      else if (has_alpha2)
-        dest[3] = src2[3];
+        if (has_alpha1 && has_alpha2)
+          dest[3] = MIN(src1[3], src2[3]);
+        else if (has_alpha2)
+          dest[3] = src2[3];
 
-      src1 += bytes1;
-      src2 += bytes2;
-      dest += bytes2;
-    }
+        src1 += bytes1;
+        src2 += bytes2;
+        dest += bytes2;
+      }
+  } else {
+    ctx->D = ctx->B;
+  }
 }
 
 /**
@@ -757,13 +774,13 @@ gimp_composite_overlay_any_any_any_generic (GimpCompositeContext * ctx)
   const guint has_alpha1 = HAS_ALPHA(bytes1);
   const guint has_alpha2 = HAS_ALPHA(bytes2);
   const guint alpha = (has_alpha1 || has_alpha2) ? MAX(bytes1, bytes2) - 1 : bytes1;
-  guint b, tmp;
+  guint b, tmp, tmpM;
 
   while (length--)
     {
       for (b = 0; b < alpha; b++)
         {
-          dest[b] = INT_MULT(src1[b], src1[b] + INT_MULT(2 * src2[b], 255 - src1[b], tmp), tmp);
+          dest[b] = INT_MULT(src1[b], src1[b] + INT_MULT(2 * src2[b], 255 - src1[b], tmpM), tmp);
         }
 
       if (has_alpha1 && has_alpha2)
