@@ -350,10 +350,10 @@ def gimp_composite_regression(fpout, function_tables, options):
             print >>fpout, '  if (gimp_composite_regression_compare_contexts ("%s", &generic_ctx, &special_ctx))' % (mode_name(mode))
             
             print >>fpout, '    {'
-            print >>fpout, '      printf("%s failed\\n");' % (mode_name(mode))
+            print >>fpout, '      printf("%s_%s_%s_%s failed\\n");' % (mode_name(mode), pixel_depth_name(A), pixel_depth_name(B), pixel_depth_name(D))
             print >>fpout, '      return (1);'
             print >>fpout, '    }'
-            print >>fpout, '  gimp_composite_regression_timer_report ("%s", ft0, ft1);' % (mode_name(mode))
+            print >>fpout, '  gimp_composite_regression_timer_report ("%s_%s_%s_%s", ft0, ft1);' % (mode_name(mode), pixel_depth_name(A), pixel_depth_name(B), pixel_depth_name(D))
             pass
           pass
         pass
@@ -466,14 +466,14 @@ def gimp_composite_cfile(fpout, name, function_table, requirements=[]):
 
 ###########################################
 
-op = optparse.OptionParser(version="$Revision: 1.15 $")
+op = optparse.OptionParser(version="$Revision: 1.17 $")
 op.add_option('-f', '--file', action='store',       type='string', dest='file',       default=None,
               help='the input object file')
 op.add_option('-t', '--test', action='store_true',                 dest='test',       default=False,
               help='generate regression testing code')
 op.add_option('-i', '--iterations', action='store', type='int',    dest='iterations', default=10,
               help='number of iterations in regression tests')
-op.add_option('-n', '--n-pixels', action='store',   type="int",    dest='n_pixels',   default=128*8192+16+1,
+op.add_option('-n', '--n-pixels', action='store',   type="int",    dest='n_pixels',   default=1024*8192+16+1,
               help='number of pixels in each regression test iteration')
 op.add_option('-r', '--requires', action='append',  type='string', dest='requires',   default=[],
               help='cpp #if conditionals')
