@@ -67,7 +67,7 @@ static GTokenType  gimp_config_deserialize_memsize     (GValue     *value,
 static GTokenType  gimp_config_deserialize_path        (GValue     *value,
                                                         GParamSpec *prop_spec,
                                                         GScanner   *scanner);
-static GTokenType  gimp_config_deserialize_color       (GValue     *value,
+static GTokenType  gimp_config_deserialize_rgb         (GValue     *value,
                                                         GParamSpec *prop_spec,
                                                         GScanner   *scanner);
 static GTokenType  gimp_config_deserialize_matrix2     (GValue     *value,
@@ -351,9 +351,9 @@ gimp_config_deserialize_value (GValue     *value,
     {
       return  gimp_config_deserialize_path (value, prop_spec, scanner);
     }
-  else if (prop_spec->value_type == GIMP_TYPE_COLOR)
+  else if (prop_spec->value_type == GIMP_TYPE_RGB)
     {
-      return gimp_config_deserialize_color (value, prop_spec, scanner);
+      return gimp_config_deserialize_rgb (value, prop_spec, scanner);
     }
   else if (prop_spec->value_type == GIMP_TYPE_MATRIX2)
     {
@@ -560,8 +560,9 @@ gimp_config_deserialize_memsize (GValue     *value,
                                  GParamSpec *prop_spec,
                                  GScanner   *scanner)
 {
-  gchar *orig_cset_first = scanner->config->cset_identifier_first;
-  gchar *orig_cset_nth   = scanner->config->cset_identifier_nth;
+  gchar   *orig_cset_first = scanner->config->cset_identifier_first;
+  gchar   *orig_cset_nth   = scanner->config->cset_identifier_nth;
+  guint64  memsize;
 
   scanner->config->cset_identifier_first = G_CSET_DIGITS;
   scanner->config->cset_identifier_nth   = G_CSET_DIGITS "gGmMkKbB";
@@ -574,10 +575,12 @@ gimp_config_deserialize_memsize (GValue     *value,
   scanner->config->cset_identifier_first = orig_cset_first;
   scanner->config->cset_identifier_nth   = orig_cset_nth;
 
-  if (gimp_memsize_set_from_string (value, scanner->value.v_identifier))
-    return G_TOKEN_RIGHT_PAREN;
-  else
+  if (! gimp_memsize_deserialize (scanner->value.v_identifier, &memsize))
     return G_TOKEN_NONE;
+
+  g_value_set_uint64 (value, memsize);
+
+  return G_TOKEN_RIGHT_PAREN;
 }
 
 static GTokenType
@@ -622,16 +625,16 @@ gimp_config_deserialize_path (GValue     *value,
 }
 
 static GTokenType
-gimp_config_deserialize_color (GValue     *value,
-                               GParamSpec *prop_spec,
-                               GScanner   *scanner)
+gimp_config_deserialize_rgb (GValue     *value,
+                             GParamSpec *prop_spec,
+                             GScanner   *scanner)
 {
-  GimpRGB color;
+  GimpRGB rgb;
 
-  if (! gimp_scanner_parse_color (scanner, &color))
+  if (! gimp_scanner_parse_color (scanner, &rgb))
     return G_TOKEN_NONE;
 
-  g_value_set_boxed (value, &color);
+  g_value_set_boxed (value, &rgb);
 
   return G_TOKEN_RIGHT_PAREN;
 }
