@@ -68,10 +68,10 @@ struct _GimpCoreConfig
   GimpGrid              *default_grid;
   gint                   levels_of_undo;
   guint64                undo_size;
-  GimpPreviewSize        undo_preview_size;
+  GimpViewSize           undo_preview_size;
   gchar                 *plug_in_rc_path;
   gboolean               layer_previews;
-  GimpPreviewSize        layer_preview_size;
+  GimpViewSize           layer_preview_size;
   GimpThumbnailSize      thumbnail_size;
   gboolean               install_cmap;
   gint                   min_colors;
