@@ -114,6 +114,7 @@ typedef struct _GimpEnvironTable    GimpEnvironTable;
 typedef struct _GimpImagefile       GimpImagefile;
 typedef struct _GimpImageMap        GimpImageMap;
 typedef struct _GimpParasiteList    GimpParasiteList;
+typedef struct _GimpPdbProgress     GimpPdbProgress;
 typedef struct _GimpProjection      GimpProjection;
 /* typedef struct _GimpTemplate     GimpTemplate; in config-types.h */
 
@@ -121,6 +122,7 @@ typedef struct _GimpProjection      GimpProjection;
 /*  interfaces  */
 
 typedef struct _GimpPickable        GimpPickable; /* dummy typedef */
+typedef struct _GimpProgress        GimpProgress; /* dummy typedef */
 
 
 /*  non-object types  */
@@ -129,7 +131,6 @@ typedef struct _GimpArea            GimpArea;
 typedef struct _GimpCoords          GimpCoords;
 typedef struct _GimpGradientSegment GimpGradientSegment;
 typedef struct _GimpGuide           GimpGuide;
-typedef struct _GimpProgress        GimpProgress;
 typedef         guint32             GimpTattoo;
 typedef struct _GimpPaletteEntry    GimpPaletteEntry;
 typedef struct _GimpPlugInDebug     GimpPlugInDebug;
