@@ -118,10 +118,9 @@ gimp_display_shell_close_dialog (GimpDisplayShell *shell,
     dialog = gimp_dialog_new (title,
                               "gimp-display-shell-close",
                               GTK_WIDGET (shell), 0,
-                              gimp_standard_help_func,
-                              GIMP_HELP_FILE_CLOSE_CONFIRM,
+                              gimp_standard_help_func, NULL,
 
-                              _("_Close without Saving"), GTK_RESPONSE_CLOSE,
+                              _("Close _without Saving"), GTK_RESPONSE_CLOSE,
                               GTK_STOCK_CANCEL,           GTK_RESPONSE_CANCEL,
                               GTK_STOCK_SAVE,             RESPONSE_SAVE,
 
