@@ -2,6 +2,8 @@
  * Copyright (C) 1995, 1996, 1997 Spencer Kimball and Peter Mattis
  * Copyright (C) 1997 Josh MacDonald
  *
+ * file-save.c
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -53,10 +55,11 @@
 #include "pdb/procedural_db.h"
 
 #include "plug-in/plug-in.h"
-#include "plug-in/plug-in-proc.h"
+#include "plug-in/plug-in-proc-def.h"
 
 #include "file-save.h"
 #include "file-utils.h"
+#include "gimprecentlist.h"
 
 #include "gimp-intl.h"
 
@@ -218,6 +221,8 @@ file_save_as (GimpImage      *gimage,
 
           GIMP_OBJECT (gimage)->name = saved_uri;
 	}
+
+      gimp_recent_list_add_uri (uri, file_proc->mime_type);
     }
   else if (status != GIMP_PDB_CANCEL)
     {
