@@ -2,6 +2,8 @@
  * Copyright (C) 1995, 1996, 1997 Spencer Kimball and Peter Mattis
  * Copyright (C) 1997 Josh MacDonald
  *
+ * file-utils.c
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -45,7 +47,7 @@
 #include "pdb/procedural_db.h"
 
 #include "plug-in/plug-in.h"
-#include "plug-in/plug-in-proc.h"
+#include "plug-in/plug-in-proc-def.h"
 
 #include "file-utils.h"
 
@@ -249,18 +251,11 @@ file_utils_uri_to_utf8_filename (const gchar *uri)
 
       if (filename)
         {
-          GError *error = NULL;
-          gchar  *utf8;
+          gchar *utf8 = g_filename_to_utf8 (filename, -1, NULL, NULL, NULL);
 
-          utf8 = g_filename_to_utf8 (filename, -1, NULL, NULL, &error);
           g_free (filename);
 
-          if (utf8)
-            return utf8;
-
-          g_warning ("%s: cannot convert filename to UTF-8: %s",
-                     G_STRLOC, error->message);
-          g_error_free (error);
+          return utf8;
         }
     }
 
