@@ -377,8 +377,10 @@ void  subsample_region                    (PixelRegion *srcPR,
                                            PixelRegion *destPR,
                                            gint         subsample);
 
-gfloat shapeburst_region                  (PixelRegion *srcPR,
-                                           PixelRegion *distPR);
+gfloat shapeburst_region                  (PixelRegion           *srcPR,
+                                           PixelRegion           *distPR,
+                                           GimpProgressFunc       progress_callback,
+                                           gpointer               progress_data);
 
 void  thin_region                         (PixelRegion *src,
                                            gint16       xradius,
@@ -401,7 +403,8 @@ void  apply_mask_to_region                (PixelRegion *src,
 /*  Combine a mask with an image's alpha channel  */
 void  combine_mask_and_region             (PixelRegion *src,
                                            PixelRegion *mask,
-                                           guint        opacity);
+                                           guint        opacity,
+                                           gboolean     stipple);
 
 /*  Copy a gray image to an intensity-alpha region  */
 void  copy_gray_to_region                 (PixelRegion *src,
