@@ -1,6 +1,8 @@
 /* The GIMP -- an image manipulation program
  * Copyright (C) 1995 Spencer Kimball and Peter Mattis
  *
+ * plug-in-message.c
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -38,7 +40,7 @@
 #include "plug-ins.h"
 #include "plug-in-def.h"
 #include "plug-in-params.h"
-#include "plug-in-proc.h"
+#include "plug-in-proc-def.h"
 #include "plug-in-shm.h"
 
 
@@ -59,7 +61,8 @@ static void plug_in_handle_tile_req         (PlugIn          *plug_in,
 static void plug_in_handle_proc_run         (PlugIn          *plug_in,
                                              GPProcRun       *proc_run);
 static void plug_in_handle_proc_return_priv (PlugIn          *plug_in,
-                                             GPProcReturn    *proc_return);
+                                             GPProcReturn    *proc_return,
+                                             gboolean         temp_proc);
 static void plug_in_handle_proc_return      (PlugIn          *plug_in,
                                              GPProcReturn    *proc_return);
 static void plug_in_handle_temp_proc_return (PlugIn          *plug_in,
@@ -343,10 +346,13 @@ static void
 plug_in_handle_proc_run (PlugIn    *plug_in,
                          GPProcRun *proc_run)
 {
-  const gchar *proc_name = NULL;
-  ProcRecord  *proc_rec;
-  Argument    *args;
-  Argument    *return_vals;
+  PlugInProcFrame *proc_frame;
+  const gchar     *proc_name = NULL;
+  ProcRecord      *proc_rec;
+  Argument        *args;
+  Argument        *return_vals;
+
+  proc_frame = plug_in_get_proc_frame (plug_in);
 
   proc_rec = procedural_db_lookup (plug_in->gimp, proc_run->name);
 
@@ -361,7 +367,7 @@ plug_in_handle_proc_run (PlugIn    *plug_in,
 
           if (plug_in->gimp->pdb_compat_mode == GIMP_PDB_COMPAT_WARN)
             {
-              g_message ("WARNING: Plug-In \"%s\"\n(%s)\n\n"
+              g_message ("WARNING: Plug-In \"%s\"\n(%s)\n"
                          "called deprecated procedure '%s'.\n"
                          "It should call '%s' instead!",
                          gimp_filename_to_utf8 (plug_in->name),
@@ -381,8 +387,11 @@ plug_in_handle_proc_run (PlugIn    *plug_in,
   /*  Execute the procedure even if procedural_db_lookup() returned NULL,
    *  procedural_db_execute() will return appropriate error return_vals.
    */
-  return_vals = procedural_db_execute (plug_in->gimp, plug_in->context,
-                                       plug_in->progress,
+  return_vals = procedural_db_execute (plug_in->gimp,
+                                       proc_frame->context_stack ?
+                                       proc_frame->context_stack->data :
+                                       proc_frame->main_context,
+                                       proc_frame->progress,
                                        proc_name, args);
 
   plug_in_pop (plug_in->gimp);
@@ -429,6 +438,11 @@ plug_in_handle_proc_run (PlugIn    *plug_in,
     {
       PlugInBlocked *blocked;
 
+      g_warning ("%s: EEEEEEEEEK! \n"
+                 "You managed to trigger a code path that \n"
+                 "should be dead. Please report this to bugs.gimp.org.",
+                 G_STRFUNC);
+
       blocked = g_new0 (PlugInBlocked, 1);
 
       blocked->plug_in   = plug_in;
@@ -440,14 +454,22 @@ plug_in_handle_proc_run (PlugIn    *plug_in,
 
 static void
 plug_in_handle_proc_return_priv (PlugIn       *plug_in,
-                                 GPProcReturn *proc_return)
+                                 GPProcReturn *proc_return,
+                                 gboolean      temp_proc)
 {
-  if (plug_in->recurse_main_loop || plug_in->temp_main_loops)
+  PlugInProcFrame *proc_frame;
+
+  if (temp_proc)
+    proc_frame = plug_in->temp_proc_frames->data;
+  else
+    proc_frame = &plug_in->main_proc_frame;
+
+  if (proc_frame->main_loop)
     {
-      plug_in->return_vals = plug_in_params_to_args (proc_return->params,
-                                                     proc_return->nparams,
-                                                     TRUE);
-      plug_in->n_return_vals = proc_return->nparams;
+      proc_frame->return_vals = plug_in_params_to_args (proc_return->params,
+                                                        proc_return->nparams,
+                                                        TRUE);
+      proc_frame->n_return_vals = proc_return->nparams;
     }
   else
     {
@@ -484,10 +506,10 @@ static void
 plug_in_handle_proc_return (PlugIn       *plug_in,
                             GPProcReturn *proc_return)
 {
-  plug_in_handle_proc_return_priv (plug_in, proc_return);
+  plug_in_handle_proc_return_priv (plug_in, proc_return, FALSE);
 
-  if (plug_in->recurse_main_loop)
-    g_main_loop_quit (plug_in->recurse_main_loop);
+  if (plug_in->main_proc_frame.main_loop)
+    g_main_loop_quit (plug_in->main_proc_frame.main_loop);
 
   plug_in_close (plug_in, FALSE);
 }
@@ -496,9 +518,9 @@ static void
 plug_in_handle_temp_proc_return (PlugIn       *plug_in,
                                  GPProcReturn *proc_return)
 {
-  if (plug_in->temp_main_loops)
+  if (plug_in->temp_proc_frames)
     {
-      plug_in_handle_proc_return_priv (plug_in, proc_return);
+      plug_in_handle_proc_return_priv (plug_in, proc_return, TRUE);
 
       plug_in_main_loop_quit (plug_in);
     }
