@@ -1,6 +1,8 @@
 /* The GIMP -- an image manipulation program
  * Copyright (C) 1995 Spencer Kimball and Peter Mattis
  *
+ * plug-in-progress.c
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -45,39 +47,43 @@ plug_in_progress_start (PlugIn      *plug_in,
                         const gchar *message,
                         gint         display_ID)
 {
+  PlugInProcFrame *proc_frame;
+
   g_return_if_fail (plug_in != NULL);
 
+  proc_frame = plug_in_get_proc_frame (plug_in);
+
   if (! message)
     message = plug_in->prog;
 
-  if (! plug_in->progress)
+  if (! proc_frame->progress)
     {
-      plug_in->progress = gimp_new_progress (plug_in->gimp, display_ID);
+      proc_frame->progress = gimp_new_progress (plug_in->gimp, display_ID);
 
-      if (plug_in->progress)
+      if (proc_frame->progress)
         {
-          plug_in->progress_created = TRUE;
+          proc_frame->progress_created = TRUE;
 
-          g_object_ref (plug_in->progress);
+          g_object_ref (proc_frame->progress);
         }
     }
 
-  if (plug_in->progress)
+  if (proc_frame->progress)
     {
-      if (! plug_in->progress_cancel_id)
-        plug_in->progress_cancel_id =
-          g_signal_connect (plug_in->progress, "cancel",
+      if (! proc_frame->progress_cancel_id)
+        proc_frame->progress_cancel_id =
+          g_signal_connect (proc_frame->progress, "cancel",
                             G_CALLBACK (plug_in_progress_cancel_callback),
                             plug_in);
 
-      if (gimp_progress_is_active (plug_in->progress))
+      if (gimp_progress_is_active (proc_frame->progress))
         {
-          gimp_progress_set_text (plug_in->progress, message);
-          gimp_progress_set_value (plug_in->progress, 0.0);
+          gimp_progress_set_text (proc_frame->progress, message);
+          gimp_progress_set_value (proc_frame->progress, 0.0);
         }
       else
         {
-          gimp_progress_start (plug_in->progress, message, TRUE);
+          gimp_progress_start (proc_frame->progress, message, TRUE);
         }
     }
 }
@@ -86,41 +92,49 @@ void
 plug_in_progress_update (PlugIn  *plug_in,
 			 gdouble  percentage)
 {
+  PlugInProcFrame *proc_frame;
+
   g_return_if_fail (plug_in != NULL);
 
-  if (! plug_in->progress                           ||
-      ! gimp_progress_is_active (plug_in->progress) ||
-      ! plug_in->progress_cancel_id)
+  proc_frame = plug_in_get_proc_frame (plug_in);
+
+  if (! proc_frame->progress                           ||
+      ! gimp_progress_is_active (proc_frame->progress) ||
+      ! proc_frame->progress_cancel_id)
     {
       plug_in_progress_start (plug_in, NULL, -1);
     }
 
-  if (plug_in->progress && gimp_progress_is_active (plug_in->progress))
-    gimp_progress_set_value (plug_in->progress, percentage);
+  if (proc_frame->progress && gimp_progress_is_active (proc_frame->progress))
+    gimp_progress_set_value (proc_frame->progress, percentage);
 }
 
 void
 plug_in_progress_end (PlugIn *plug_in)
 {
+  PlugInProcFrame *proc_frame;
+
   g_return_if_fail (plug_in != NULL);
 
-  if (plug_in->progress)
+  proc_frame = plug_in_get_proc_frame (plug_in);
+
+  if (proc_frame->progress)
     {
-      if (plug_in->progress_cancel_id)
+      if (proc_frame->progress_cancel_id)
         {
-          g_signal_handler_disconnect (plug_in->progress,
-                                       plug_in->progress_cancel_id);
-          plug_in->progress_cancel_id = 0;
+          g_signal_handler_disconnect (proc_frame->progress,
+                                       proc_frame->progress_cancel_id);
+          proc_frame->progress_cancel_id = 0;
         }
 
-      if (gimp_progress_is_active (plug_in->progress))
-        gimp_progress_end (plug_in->progress);
+      if (gimp_progress_is_active (proc_frame->progress))
+        gimp_progress_end (proc_frame->progress);
 
-      if (plug_in->progress_created)
+      if (proc_frame->progress_created)
         {
-          gimp_free_progress (plug_in->gimp, plug_in->progress);
-          g_object_unref (plug_in->progress);
-          plug_in->progress = NULL;
+          gimp_free_progress (plug_in->gimp, proc_frame->progress);
+          g_object_unref (proc_frame->progress);
+          proc_frame->progress = NULL;
         }
     }
 }
@@ -129,7 +143,8 @@ gboolean
 plug_in_progress_install (PlugIn      *plug_in,
                           const gchar *progress_callback)
 {
-  ProcRecord *proc_rec;
+  PlugInProcFrame *proc_frame;
+  ProcRecord      *proc_rec;
 
   g_return_val_if_fail (plug_in != NULL, FALSE);
   g_return_val_if_fail (progress_callback != NULL, FALSE);
@@ -147,21 +162,23 @@ plug_in_progress_install (PlugIn      *plug_in,
       return FALSE;
     }
 
-  if (plug_in->progress)
+  proc_frame = plug_in_get_proc_frame (plug_in);
+
+  if (proc_frame->progress)
     {
       plug_in_progress_end (plug_in);
 
-      if (plug_in->progress)
+      if (proc_frame->progress)
         {
-          g_object_unref (plug_in->progress);
-          plug_in->progress = NULL;
+          g_object_unref (proc_frame->progress);
+          proc_frame->progress = NULL;
         }
     }
 
-  plug_in->progress = g_object_new (GIMP_TYPE_PDB_PROGRESS,
-                                    "context",       plug_in->context,
-                                    "callback-name", progress_callback,
-                                    NULL);
+  proc_frame->progress = g_object_new (GIMP_TYPE_PDB_PROGRESS,
+                                       "context",       proc_frame->main_context,
+                                       "callback-name", progress_callback,
+                                       NULL);
 
   return TRUE;
 }
@@ -170,14 +187,18 @@ gboolean
 plug_in_progress_uninstall (PlugIn      *plug_in,
                             const gchar *progress_callback)
 {
+  PlugInProcFrame *proc_frame;
+
   g_return_val_if_fail (plug_in != NULL, FALSE);
   g_return_val_if_fail (progress_callback != NULL, FALSE);
 
-  if (GIMP_IS_PDB_PROGRESS (plug_in->progress))
+  proc_frame = plug_in_get_proc_frame (plug_in);
+
+  if (GIMP_IS_PDB_PROGRESS (proc_frame->progress))
     {
       plug_in_progress_end (plug_in);
-      g_object_unref (plug_in->progress);
-      plug_in->progress = NULL;
+      g_object_unref (proc_frame->progress);
+      proc_frame->progress = NULL;
 
       return TRUE;
     }
@@ -202,13 +223,30 @@ static void
 plug_in_progress_cancel_callback (GimpProgress *progress,
                                   PlugIn       *plug_in)
 {
-  if (plug_in->recurse_main_loop || plug_in->temp_main_loops)
-    {
-      plug_in->return_vals   = g_new (Argument, 1);
-      plug_in->n_return_vals = 1;
+  PlugInProcFrame *proc_frame = &plug_in->main_proc_frame;
+  GList           *list;
 
-      plug_in->return_vals->arg_type      = GIMP_PDB_STATUS;
-      plug_in->return_vals->value.pdb_int = GIMP_PDB_CANCEL;
+  if (proc_frame->main_loop)
+    {
+      proc_frame->return_vals   = g_new (Argument, 1);
+      proc_frame->n_return_vals = 1;
+
+      proc_frame->return_vals->arg_type      = GIMP_PDB_STATUS;
+      proc_frame->return_vals->value.pdb_int = GIMP_PDB_CANCEL;
+    }
+
+  for (list = plug_in->temp_proc_frames; list; list = g_list_next (list))
+    {
+      proc_frame = list->data;
+
+      if (proc_frame->main_loop)
+        {
+          proc_frame->return_vals   = g_new (Argument, 1);
+          proc_frame->n_return_vals = 1;
+
+          proc_frame->return_vals->arg_type      = GIMP_PDB_STATUS;
+          proc_frame->return_vals->value.pdb_int = GIMP_PDB_CANCEL;
+        }
     }
 
   plug_in_close (plug_in, TRUE);
