@@ -1,6 +1,8 @@
 /* The GIMP -- an image manipulation program
  * Copyright (C) 1995 Spencer Kimball and Peter Mattis
  *
+ * plug-in-run.c
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -40,7 +42,7 @@
 
 #include "plug-in.h"
 #include "plug-in-params.h"
-#include "plug-in-proc.h"
+#include "plug-in-proc-def.h"
 #include "plug-in-run.h"
 #include "plug-in-shm.h"
 
@@ -49,12 +51,13 @@
 
 /*  local function prototypes  */
 
-static Argument * plug_in_temp_run        (ProcRecord   *proc_rec,
-                                           GimpProgress *progress,
-                                           Argument     *args,
-                                           gint          argc);
-static Argument * plug_in_get_return_vals (PlugIn       *plug_in,
-                                           ProcRecord   *proc_rec);
+static Argument * plug_in_temp_run        (ProcRecord      *proc_rec,
+                                           GimpContext     *context,
+                                           GimpProgress    *progress,
+                                           Argument        *args,
+                                           gint             argc);
+static Argument * plug_in_get_return_vals (PlugIn          *plug_in,
+                                           PlugInProcFrame *proc_frame);
 
 
 /*  public functions  */
@@ -81,18 +84,20 @@ plug_in_run (Gimp         *gimp,
 
   if (proc_rec->proc_type == GIMP_TEMPORARY)
     {
-      return_vals = plug_in_temp_run (proc_rec, progress, args, argc);
+      return_vals = plug_in_temp_run (proc_rec, context, progress, args, argc);
       goto done;
     }
 
-  plug_in = plug_in_new (gimp, context, proc_rec,
+  plug_in = plug_in_new (gimp, context, progress, proc_rec,
                          proc_rec->exec_method.plug_in.filename);
 
   if (plug_in)
     {
-      GPConfig  config;
-      GPProcRun proc_run;
-      gint      monitor;
+      GimpDisplayConfig *display_config = GIMP_DISPLAY_CONFIG (gimp->config);
+      GimpGuiConfig     *gui_config = GIMP_GUI_CONFIG (gimp->config);
+      GPConfig           config;
+      GPProcRun          proc_run;
+      gint               monitor;
 
       if (! plug_in_open (plug_in))
 	{
@@ -100,29 +105,27 @@ plug_in_run (Gimp         *gimp,
           goto done;
         }
 
-      if (progress)
-        plug_in->progress = g_object_ref (progress);
-
-      config.version         = GIMP_PROTOCOL_VERSION;
-      config.tile_width      = TILE_WIDTH;
-      config.tile_height     = TILE_HEIGHT;
-      config.shm_ID          = plug_in_shm_get_ID (gimp);
-      config.check_size      = GIMP_DISPLAY_CONFIG (gimp->config)->transparency_size;
-      config.check_type      = GIMP_DISPLAY_CONFIG (gimp->config)->transparency_type;
-      config.gimp_reserved_3 = 0;
-      config.gimp_reserved_4 = 0;
-      config.gimp_reserved_5 = 0;
-      config.gimp_reserved_6 = 0;
-      config.gimp_reserved_7 = 0;
-      config.gimp_reserved_8 = 0;
-      config.install_cmap    = gimp->config->install_cmap;
-      config.show_tool_tips  = GIMP_GUI_CONFIG (gimp->config)->show_tool_tips;
-      config.min_colors      = CLAMP (gimp->config->min_colors, 27, 256);
-      config.gdisp_ID        = gdisp_ID;
-      config.app_name        = (gchar *) g_get_application_name ();
-      config.wm_class        = (gchar *) gimp_get_program_class (gimp);
-      config.display_name    = gimp_get_display_name (gimp, gdisp_ID, &monitor);
-      config.monitor_number  = monitor;
+      config.version          = GIMP_PROTOCOL_VERSION;
+      config.tile_width       = TILE_WIDTH;
+      config.tile_height      = TILE_HEIGHT;
+      config.shm_ID           = plug_in_shm_get_ID (gimp);
+      config.check_size       = display_config->transparency_size;
+      config.check_type       = display_config->transparency_type;
+      config.show_help_button = (gui_config->use_help &&
+                                 gui_config->show_help_button);
+      config.gimp_reserved_4  = 0;
+      config.gimp_reserved_5  = 0;
+      config.gimp_reserved_6  = 0;
+      config.gimp_reserved_7  = 0;
+      config.gimp_reserved_8  = 0;
+      config.install_cmap     = gimp->config->install_cmap;
+      config.show_tool_tips   = gui_config->show_tool_tips;
+      config.min_colors       = CLAMP (gimp->config->min_colors, 27, 256);
+      config.gdisp_ID         = gdisp_ID;
+      config.app_name         = (gchar *) g_get_application_name ();
+      config.wm_class         = (gchar *) gimp_get_program_class (gimp);
+      config.display_name     = gimp_get_display_name (gimp, gdisp_ID, &monitor);
+      config.monitor_number   = monitor;
 
       proc_run.name    = proc_rec->name;
       proc_run.nparams = argc;
@@ -165,16 +168,17 @@ plug_in_run (Gimp         *gimp,
        */
       if (synchronous)
         {
-          plug_in->recurse_main_loop = g_main_loop_new (NULL, FALSE);
+          plug_in->main_proc_frame.main_loop = g_main_loop_new (NULL, FALSE);
 
           gimp_threads_leave (gimp);
-          g_main_loop_run (plug_in->recurse_main_loop);
+          g_main_loop_run (plug_in->main_proc_frame.main_loop);
           gimp_threads_enter (gimp);
 
-          g_main_loop_unref (plug_in->recurse_main_loop);
-          plug_in->recurse_main_loop = NULL;
+          g_main_loop_unref (plug_in->main_proc_frame.main_loop);
+          plug_in->main_proc_frame.main_loop = NULL;
 
-          return_vals = plug_in_get_return_vals (plug_in, proc_rec);
+          return_vals = plug_in_get_return_vals (plug_in,
+                                                 &plug_in->main_proc_frame);
         }
 
       plug_in_unref (plug_in);
@@ -234,6 +238,7 @@ plug_in_repeat (Gimp         *gimp,
 
 static Argument *
 plug_in_temp_run (ProcRecord   *proc_rec,
+                  GimpContext  *context,
                   GimpProgress *progress,
 		  Argument     *args,
 		  gint          argc)
@@ -247,8 +252,7 @@ plug_in_temp_run (ProcRecord   *proc_rec,
     {
       GPProcRun proc_run;
 
-      plug_in->temp_proc_recs = g_list_prepend (plug_in->temp_proc_recs,
-                                                proc_rec);
+      plug_in_proc_frame_push (plug_in, context, progress, proc_rec);
 
       proc_run.name    = proc_rec->name;
       proc_run.nparams = argc;
@@ -259,8 +263,7 @@ plug_in_temp_run (ProcRecord   *proc_rec,
 	{
 	  return_vals = procedural_db_return_args (proc_rec, FALSE);
 
-          plug_in->temp_proc_recs = g_list_remove (plug_in->temp_proc_recs,
-                                                   proc_rec);
+          plug_in_proc_frame_pop (plug_in);
 
 	  goto done;
 	}
@@ -271,10 +274,10 @@ plug_in_temp_run (ProcRecord   *proc_rec,
 
       plug_in_main_loop (plug_in);
 
-      return_vals = plug_in_get_return_vals (plug_in, proc_rec);
+      return_vals = plug_in_get_return_vals (plug_in,
+                                             plug_in->temp_proc_frames->data);
 
-      plug_in->temp_proc_recs = g_list_remove (plug_in->temp_proc_recs,
-                                               proc_rec);
+      plug_in_proc_frame_pop (plug_in);
 
       plug_in_unref (plug_in);
     }
@@ -284,46 +287,46 @@ plug_in_temp_run (ProcRecord   *proc_rec,
 }
 
 static Argument *
-plug_in_get_return_vals (PlugIn     *plug_in,
-                         ProcRecord *proc_rec)
+plug_in_get_return_vals (PlugIn          *plug_in,
+                         PlugInProcFrame *proc_frame)
 {
   Argument *return_vals;
   gint      nargs;
 
   g_return_val_if_fail (plug_in != NULL, NULL);
-  g_return_val_if_fail (proc_rec != NULL, NULL);
+  g_return_val_if_fail (proc_frame != NULL, NULL);
 
   /* Return the status code plus the current return values. */
-  nargs = proc_rec->num_values + 1;
+  nargs = proc_frame->proc_rec->num_values + 1;
 
-  if (plug_in->return_vals && plug_in->n_return_vals == nargs)
+  if (proc_frame->return_vals && proc_frame->n_return_vals == nargs)
     {
-      return_vals = plug_in->return_vals;
+      return_vals = proc_frame->return_vals;
     }
-  else if (plug_in->return_vals)
+  else if (proc_frame->return_vals)
     {
       /* Allocate new return values of the correct size. */
-      return_vals = procedural_db_return_args (proc_rec, FALSE);
+      return_vals = procedural_db_return_args (proc_frame->proc_rec, FALSE);
 
       /* Copy all of the arguments we can. */
-      memcpy (return_vals, plug_in->return_vals,
-	      sizeof (Argument) * MIN (plug_in->n_return_vals, nargs));
+      memcpy (return_vals, proc_frame->return_vals,
+	      sizeof (Argument) * MIN (proc_frame->n_return_vals, nargs));
 
       /* Free the old argument pointer.  This will cause a memory leak
        * only if there were more values returned than we need (which
        * shouldn't ever happen).
        */
-      g_free (plug_in->return_vals);
+      g_free (proc_frame->return_vals);
     }
   else
     {
       /* Just return a dummy set of values. */
-      return_vals = procedural_db_return_args (proc_rec, FALSE);
+      return_vals = procedural_db_return_args (proc_frame->proc_rec, FALSE);
     }
 
   /* We have consumed any saved values, so clear them. */
-  plug_in->return_vals   = NULL;
-  plug_in->n_return_vals = 0;
+  proc_frame->return_vals   = NULL;
+  proc_frame->n_return_vals = 0;
 
   return return_vals;
 }
