@@ -83,8 +83,7 @@ static void       gimp_vectors_scale        (GimpItem         *item,
                                              gint              new_offset_x,
                                              gint              new_offset_y,
                                              GimpInterpolationType  interp_type,
-                                             GimpProgressFunc       progress_callback,
-                                             gpointer               progress_data);
+                                             GimpProgress     *progress);
 static void       gimp_vectors_resize       (GimpItem         *item,
                                              GimpContext      *context,
                                              gint              new_width,
@@ -110,16 +109,12 @@ static void       gimp_vectors_transform    (GimpItem         *item,
                                              gboolean          supersample,
                                              gint              recursion_level,
                                              gboolean          clip_result,
-                                             GimpProgressFunc  progress_callback,
-                                             gpointer          progress_data);
+                                             GimpProgress     *progress);
 static gboolean   gimp_vectors_stroke       (GimpItem         *item,
                                              GimpDrawable     *drawable,
                                              GimpContext      *context,
-                                             GimpObject       *stroke_desc,
-                                             gboolean          use_default_values);
+                                             GimpObject       *stroke_desc);
 
-
-#
 static void       gimp_vectors_real_thaw            (GimpVectors       *vectors);
 static void       gimp_vectors_real_stroke_add      (GimpVectors       *vectors,
                                                      GimpStroke        *stroke);
@@ -395,8 +390,7 @@ gimp_vectors_scale (GimpItem              *item,
                     gint                   new_offset_x,
                     gint                   new_offset_y,
                     GimpInterpolationType  interpolation_type,
-                    GimpProgressFunc       progress_callback,
-                    gpointer               progress_data)
+                    GimpProgress          *progress)
 {
   GimpVectors *vectors = GIMP_VECTORS (item);
   GimpImage   *image   = gimp_item_get_image (item);
@@ -417,8 +411,7 @@ gimp_vectors_scale (GimpItem              *item,
     }
 
   GIMP_ITEM_CLASS (parent_class)->scale (item, image->width, image->height,
-                                         0, 0, interpolation_type,
-                                         progress_callback, progress_data);
+                                         0, 0, interpolation_type, progress);
 
   gimp_vectors_thaw (vectors);
 }
@@ -534,8 +527,7 @@ gimp_vectors_transform (GimpItem               *item,
                         gboolean                supersample,
                         gint                    recursion_level,
                         gboolean                clip_result,
-                        GimpProgressFunc        progress_callback,
-                        gpointer                progress_data)
+                        GimpProgress           *progress)
 {
   GimpVectors *vectors = GIMP_VECTORS (item);
   GimpMatrix3  local_matrix;
@@ -566,8 +558,7 @@ static gboolean
 gimp_vectors_stroke (GimpItem     *item,
                      GimpDrawable *drawable,
                      GimpContext  *context,
-                     GimpObject   *stroke_desc,
-                     gboolean      use_default_values)
+                     GimpObject   *stroke_desc)
 {
   GimpVectors *vectors = GIMP_VECTORS (item);
   gboolean     retval  = FALSE;
@@ -585,42 +576,18 @@ gimp_vectors_stroke (GimpItem     *item,
                                     vectors);
       retval = TRUE;
     }
-  else if (GIMP_IS_PAINT_INFO (stroke_desc))
+  else if (GIMP_IS_PAINT_OPTIONS (stroke_desc))
     {
-      GimpImage        *gimage     = gimp_item_get_image (item);
-      GimpPaintInfo    *paint_info = GIMP_PAINT_INFO (stroke_desc);
-      GimpPaintOptions *paint_options;
+      GimpPaintOptions *paint_options = GIMP_PAINT_OPTIONS (stroke_desc);
       GimpPaintCore    *core;
 
-      if (use_default_values)
-        {
-          paint_options =
-            gimp_paint_options_new (gimage->gimp,
-                                    paint_info->paint_options_type);
-
-          /*  undefine the paint-relevant context properties and get them
-           *  from the passed context
-           */
-          gimp_context_define_properties (GIMP_CONTEXT (paint_options),
-                                          GIMP_CONTEXT_PAINT_PROPS_MASK,
-                                          FALSE);
-          gimp_context_set_parent (GIMP_CONTEXT (paint_options), context);
-        }
-      else
-        {
-          paint_options = paint_info->paint_options;
-        }
-
-      core = g_object_new (paint_info->paint_type, NULL);
+      core = g_object_new (paint_options->paint_info->paint_type, NULL);
 
       retval = gimp_paint_core_stroke_vectors (core, drawable,
                                                paint_options,
                                                vectors);
 
       g_object_unref (core);
-
-      if (use_default_values)
-        g_object_unref (paint_options);
     }
 
   return retval;
