@@ -45,7 +45,7 @@ enum
   PROP_0,
   PROP_STROKE_OPTIONS,
   PROP_N_SEGMENTS,
-  PROP_LENGTH,
+  PROP_LENGTH
 };
 
 
