@@ -34,9 +34,6 @@
  */
 
 /* TODO:
- *
- * - Fix memory leaks: grad_free_gradient_editor() and any others
- * which I may have missed.
  *
  * - Add all of Marcelo's neat suggestions:
  *   - Hue rotate, saturation, brightness, contrast.
@@ -73,8 +70,6 @@
 #include "gimpviewrenderergradient.h"
 #include "gimpwidgets-utils.h"
 
-#include "dialogs/color-dialog.h"
-
 #include "gimp-intl.h"
 
 
@@ -463,7 +458,7 @@ gimp_gradient_editor_set_data (GimpDataEditor *editor,
 
   if (gradient_editor->color_dialog)
     {
-      color_dialog_free (gradient_editor->color_dialog);
+      gtk_widget_destroy (gradient_editor->color_dialog);
       gradient_editor->color_dialog = NULL;
       gtk_widget_set_sensitive (GTK_WIDGET (editor), TRUE);
     }
@@ -508,24 +503,23 @@ gimp_gradient_editor_gradient_dirty (GimpGradientEditor *editor,
 
 /*  public functions  */
 
-GimpDataEditor *
+GtkWidget *
 gimp_gradient_editor_new (Gimp            *gimp,
                           GimpMenuFactory *menu_factory)
 {
-  GimpGradientEditor *editor;
+  GimpGradient *gradient;
 
-  editor = g_object_new (GIMP_TYPE_GRADIENT_EDITOR, NULL);
+  g_return_val_if_fail (GIMP_IS_GIMP (gimp), NULL);
 
-  if (! gimp_data_editor_construct (GIMP_DATA_EDITOR (editor),
-                                    gimp->gradient_factory,
-                                    menu_factory, "<GradientEditor>",
-                                    "/gradient-editor-popup"))
-    {
-      g_object_unref (editor);
-      return NULL;
-    }
+  gradient = gimp_context_get_gradient (gimp_get_user_context (gimp));
 
-  return GIMP_DATA_EDITOR (editor);
+  return g_object_new (GIMP_TYPE_GRADIENT_EDITOR,
+                       "menu-factory",    menu_factory,
+                       "menu-identifier", "<GradientEditor>",
+                       "ui-path",         "/gradient-editor-popup",
+                       "data-factory",    gimp->gradient_factory,
+                       "data",            gradient,
+                       NULL);
 }
 
 void
