@@ -39,6 +39,7 @@
 #include "core/gimpdatafactory.h"
 #include "core/gimppalette.h"
 
+#include "gimpcolordialog.h"
 #include "gimpdialogfactory.h"
 #include "gimpdnd.h"
 #include "gimpdocked.h"
@@ -47,8 +48,6 @@
 #include "gimpsessioninfo.h"
 #include "gimpwidgets-utils.h"
 
-#include "dialogs/color-dialog.h"
-
 #include "gimp-intl.h"
 
 
@@ -138,10 +137,10 @@ static void   palette_editor_viewport_resized      (GtkWidget         *widget,
 static void   palette_editor_viewport_realize      (GtkWidget         *widget,
                                                     GimpPaletteEditor *editor);
 
-static void   palette_editor_color_dialog_callback (ColorDialog       *color_dialog,
+static void   palette_editor_color_dialog_update   (GimpColorDialog   *dialog,
                                                     const GimpRGB     *color,
-                                                    ColorDialogState   state,
-                                                    gpointer           data);
+                                                    GimpColorDialogState  state,
+                                                    GimpPaletteEditor *editor);
 
 
 static GimpDataEditorClass *parent_class        = NULL;
@@ -412,7 +411,7 @@ gimp_palette_editor_destroy (GtkObject *object)
 
   if (editor->color_dialog)
     {
-      color_dialog_free (editor->color_dialog);
+      gtk_widget_destroy (editor->color_dialog);
       editor->color_dialog = NULL;
     }
 
@@ -425,7 +424,7 @@ gimp_palette_editor_unmap (GtkWidget *widget)
   GimpPaletteEditor *editor = GIMP_PALETTE_EDITOR (widget);
 
   if (editor->color_dialog)
-    color_dialog_hide (editor->color_dialog);
+    gtk_widget_hide (editor->color_dialog);
 
   GTK_WIDGET_CLASS (parent_class)->unmap (widget);
 }
@@ -444,7 +443,7 @@ gimp_palette_editor_set_data (GimpDataEditor *editor,
     {
       if (palette_editor->color_dialog)
         {
-          color_dialog_free (palette_editor->color_dialog);
+          gtk_widget_destroy (palette_editor->color_dialog);
           palette_editor->color_dialog = NULL;
         }
 
@@ -497,24 +496,23 @@ gimp_palette_editor_set_data (GimpDataEditor *editor,
 
 /*  public functions  */
 
-GimpDataEditor *
+GtkWidget *
 gimp_palette_editor_new (Gimp            *gimp,
                          GimpMenuFactory *menu_factory)
 {
-  GimpPaletteEditor *palette_editor;
+  GimpPalette *palette;
 
-  palette_editor = g_object_new (GIMP_TYPE_PALETTE_EDITOR, NULL);
+  g_return_val_if_fail (GIMP_IS_GIMP (gimp), NULL);
 
-  if (! gimp_data_editor_construct (GIMP_DATA_EDITOR (palette_editor),
-                                    gimp->palette_factory,
-                                    menu_factory, "<PaletteEditor>",
-                                    "/palette-editor-popup"))
-    {
-      g_object_unref (palette_editor);
-      return NULL;
-    }
+  palette = gimp_context_get_palette (gimp_get_user_context (gimp));
 
-  return GIMP_DATA_EDITOR (palette_editor);
+  return g_object_new (GIMP_TYPE_PALETTE_EDITOR,
+                       "menu-factory",    menu_factory,
+                       "menu-identifier", "<PaletteEditor>",
+                       "ui-path",         "/palette-editor-popup",
+                       "data-factory",    gimp->palette_factory,
+                       "data",            palette,
+                       NULL);
 }
 
 void
@@ -538,10 +536,9 @@ gimp_palette_editor_pick_color (GimpPaletteEditor  *editor,
 
         case GIMP_COLOR_PICK_STATE_UPDATE:
           editor->color->color = *color;
+          gimp_data_dirty (data);
           break;
         }
-
-      gimp_data_dirty (data);
     }
 }
 
@@ -950,7 +947,6 @@ palette_editor_redraw (GimpPaletteEditor *editor,
                                  editor->color->position % editor->columns);
 }
 
-
 static void
 palette_editor_select_entry (GimpPaletteEditor *editor,
                              GimpPaletteEntry  *entry)
@@ -1045,24 +1041,33 @@ palette_editor_edit_clicked (GtkWidget         *widget,
       toplevel_factory = gimp_dialog_factory_from_name ("toplevel");
 
       editor->color_dialog =
-	color_dialog_new (GIMP_VIEWABLE (palette),
-                          _("Edit Palette Color"),
-                          GIMP_STOCK_PALETTE,
-                          _("Edit Color Palette Entry"),
-                          GTK_WIDGET (editor),
-                          toplevel_factory,
-                          "gimp-palette-editor-color-dialog",
-                          (const GimpRGB *) &editor->color->color,
-                          palette_editor_color_dialog_callback,
-                          editor,
-                          FALSE, FALSE);
+	gimp_color_dialog_new (GIMP_VIEWABLE (palette),
+                               _("Edit Palette Color"),
+                               GIMP_STOCK_PALETTE,
+                               _("Edit Color Palette Entry"),
+                               GTK_WIDGET (editor),
+                               toplevel_factory,
+                               "gimp-palette-editor-color-dialog",
+                               (const GimpRGB *) &editor->color->color,
+                               FALSE, FALSE);
+
+      g_signal_connect (editor->color_dialog, "destroy",
+                        G_CALLBACK (gtk_widget_destroyed),
+                        &editor->color_dialog);
+
+      g_signal_connect (editor->color_dialog, "update",
+                        G_CALLBACK (palette_editor_color_dialog_update),
+                        editor);
     }
   else
     {
-      color_dialog_set_viewable (editor->color_dialog, GIMP_VIEWABLE (palette));
-      color_dialog_set_color (editor->color_dialog, &editor->color->color);
-      color_dialog_show (editor->color_dialog);
+      gimp_viewable_dialog_set_viewable (GIMP_VIEWABLE_DIALOG (editor->color_dialog),
+                                         GIMP_VIEWABLE (palette));
+      gimp_color_dialog_set_color (GIMP_COLOR_DIALOG (editor->color_dialog),
+                                   &editor->color->color);
     }
+
+  gtk_window_present (GTK_WINDOW (editor->color_dialog));
 }
 
 static void
@@ -1225,8 +1230,20 @@ static void
 palette_editor_invalidate_preview (GimpPalette       *palette,
 				   GimpPaletteEditor *editor)
 {
-  if (editor->color && ! g_list_find (palette->colors, editor->color))
-    palette_editor_select_entry (editor, NULL);
+  if (editor->color)
+    {
+      GimpPaletteEntry *entry = editor->color;
+
+      if (g_list_find (palette->colors, entry))
+        {
+          editor->color = NULL;
+          palette_editor_select_entry (editor, entry);
+        }
+      else
+        {
+          palette_editor_select_entry (editor, NULL);
+        }
+    }
 
   if (editor->dnd_color && ! g_list_find (palette->colors, editor->dnd_color))
     editor->dnd_color = NULL;
@@ -1262,33 +1279,28 @@ palette_editor_viewport_realize (GtkWidget         *widget,
 }
 
 static void
-palette_editor_color_dialog_callback (ColorDialog      *color_dialog,
-                                      const GimpRGB    *color,
-                                      ColorDialogState  state,
-                                      gpointer          data)
+palette_editor_color_dialog_update (GimpColorDialog      *dialog,
+                                    const GimpRGB        *color,
+                                    GimpColorDialogState  state,
+                                    GimpPaletteEditor    *editor)
 {
-  GimpPaletteEditor *editor = GIMP_PALETTE_EDITOR (data);
-  GimpPalette       *palette;
-  GimpContext       *user_context;
-
-  palette = GIMP_PALETTE (GIMP_DATA_EDITOR (editor)->data);
-
-  user_context = gimp_get_user_context (GIMP_DATA_EDITOR (editor)->data_factory->gimp);
+  GimpPalette *palette = GIMP_PALETTE (GIMP_DATA_EDITOR (editor)->data);
 
   switch (state)
     {
-    case COLOR_DIALOG_UPDATE:
+    case GIMP_COLOR_DIALOG_UPDATE:
       break;
 
-    case COLOR_DIALOG_OK:
+    case GIMP_COLOR_DIALOG_OK:
       if (editor->color)
 	{
 	  editor->color->color = *color;
 	  gimp_data_dirty (GIMP_DATA (palette));
 	}
-
       /* Fallthrough */
-    case COLOR_DIALOG_CANCEL:
-      color_dialog_hide (editor->color_dialog);
+
+    case GIMP_COLOR_DIALOG_CANCEL:
+      gtk_widget_hide (editor->color_dialog);
+      break;
     }
 }
