@@ -40,6 +40,9 @@ struct _GimpThumbBox
   GtkWidget     *preview;
   GtkWidget     *filename;
   GtkWidget     *info;
+  GtkWidget     *thumb_progress;
+
+  gboolean       progress_active;
   GtkWidget     *progress;
 };
 
