@@ -77,12 +77,6 @@ gimp_menu_position (GtkMenu *menu,
 
   gtk_menu_set_screen (menu, screen);
 
-#ifdef __GNUC__
-#warning FIXME: remove this hack as soon as we depend on GTK+ 2.4.4
-#endif
-  if (gtk_check_version (2, 4, 4))
-    gtk_menu_set_monitor (menu, monitor);
-
   gtk_widget_size_request (widget, &requisition);
 
   if (gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL)
@@ -156,12 +150,6 @@ gimp_button_menu_position (GtkWidget       *button,
 
   gtk_menu_set_screen (menu, screen);
 
-#ifdef __GNUC__
-#warning FIXME: remove this hack as soon as we depend on GTK+ 2.4.4
-#endif
-  if (gtk_check_version (2, 4, 4))
-    gtk_menu_set_monitor (menu, monitor);
-
   *x += button->allocation.x;
 
   switch (position)
