@@ -23,12 +23,6 @@
 #define __GIMP_WIDGETS_UTILS_H__
 
 
-void          gimp_message_box           (const gchar     *stock_id,
-                                          const gchar     *domain,
-                                          const gchar     *message,
-                                          GtkCallback      callback,
-                                          gpointer         data);
-
 void          gimp_menu_position         (GtkMenu         *menu,
                                           gint            *x,
                                           gint            *y);
@@ -72,5 +66,8 @@ void          gimp_rgb_set_gdk_color     (GimpRGB         *rgb,
 void          gimp_window_set_hint       (GtkWindow       *window,
                                           GimpWindowHint   hint);
 
+void          gimp_dialog_set_sensitive  (GtkDialog       *dialog,
+                                          gboolean         sensitive);
+
 
 #endif /* __GIMP_WIDGETS_UTILS_H__ */
