@@ -122,6 +122,7 @@ typedef struct _GimpUIManager                GimpUIManager;
 
 /*  misc dialogs  */
 
+typedef struct _GimpColorDialog              GimpColorDialog;
 typedef struct _GimpErrorDialog              GimpErrorDialog;
 typedef struct _GimpFileDialog               GimpFileDialog;
 typedef struct _GimpProgressDialog           GimpProgressDialog;
@@ -133,7 +134,6 @@ typedef struct _GimpViewableDialog           GimpViewableDialog;
 /*  GimpPdbDialog widgets  */
 
 typedef struct _GimpPdbDialog                GimpPdbDialog;
-typedef struct _GimpDataSelect               GimpDataSelect;
 typedef struct _GimpBrushSelect              GimpBrushSelect;
 typedef struct _GimpGradientSelect           GimpGradientSelect;
 typedef struct _GimpPaletteSelect            GimpPaletteSelect;
@@ -213,9 +213,6 @@ typedef struct _GimpSessionInfoAux           GimpSessionInfoAux;
 
 /*  function types  */
 
-typedef void (* GimpDataEditFunc)          (GimpData        *data,
-                                            GtkWidget       *parent);
-
 typedef void (* GimpActionGroupSetupFunc)  (GimpActionGroup *group);
 typedef void (* GimpActionGroupUpdateFunc) (GimpActionGroup *group,
                                             gpointer         data);
