@@ -31,14 +31,19 @@
 #include <libgimp/gimpenums.h>
 #include <libgimp/gimptypes.h>
 
+#include <libgimp/gimpbrushes.h>
 #include <libgimp/gimpbrushselect.h>
 #include <libgimp/gimpchannel.h>
 #include <libgimp/gimpdrawable.h>
 #include <libgimp/gimpfontselect.h>
+#include <libgimp/gimpgradients.h>
 #include <libgimp/gimpgradientselect.h>
 #include <libgimp/gimpimage.h>
 #include <libgimp/gimplayer.h>
+#include <libgimp/gimppalette.h>
+#include <libgimp/gimppalettes.h>
 #include <libgimp/gimppaletteselect.h>
+#include <libgimp/gimppatterns.h>
 #include <libgimp/gimppatternselect.h>
 #include <libgimp/gimppixelfetcher.h>
 #include <libgimp/gimppixelrgn.h>
@@ -310,6 +315,7 @@ gdouble       gimp_gamma               (void) G_GNUC_CONST;
 gboolean      gimp_install_cmap        (void) G_GNUC_CONST;
 gint          gimp_min_colors          (void) G_GNUC_CONST;
 gboolean      gimp_show_tool_tips      (void) G_GNUC_CONST;
+gboolean      gimp_show_help_button    (void) G_GNUC_CONST;
 GimpCheckSize gimp_check_size          (void) G_GNUC_CONST;
 GimpCheckType gimp_check_type          (void) G_GNUC_CONST;
 gint32        gimp_default_display     (void) G_GNUC_CONST;
