@@ -216,7 +216,7 @@ gimp_color_scales_init (GimpColorScales *scales)
       scales->slider_data[i] =
         gimp_color_scale_entry_new (GTK_TABLE (table), 1, i,
                                     gettext (toggle_titles[i]),
-                                    80, -1,
+                                    -1, -1,
                                     slider_initial_vals[i],
                                     0.0, slider_max_vals[i],
                                     1.0, slider_incs[i],
@@ -468,4 +468,6 @@ gimp_color_scales_entry_changed (GimpColorHexEntry *entry,
 
   gimp_rgb_to_hsv (&selector->rgb, &selector->hsv);
   gimp_color_scales_update_scales (scales, -1);
+
+  gimp_color_selector_color_changed (selector);
 }
