@@ -48,26 +48,19 @@ struct _GimpPreview
 
   /*< protected >*/
   GtkWidget    *area;
+  GtkWidget    *table;
   GtkWidget    *frame;
-  GtkWidget    *hscr;
-  GtkWidget    *vscr;
-  GtkWidget    *nav_icon;
-  GtkWidget    *nav_popup;
   GtkWidget    *toggle;
-  GdkCursor    *cursor_move;
   GdkCursor    *cursor_busy;
-  GdkGC        *nav_gc;
 
   /*< private >*/
   gint          xoff, yoff;
   gint          xmin, xmax, ymin, ymax;
-  gint          drag_x, drag_y;
-  gint          drag_xoff, drag_yoff;
   gint          width, height;
 
-  gboolean      in_drag;
   guint         timeout_id;
 };
+
 struct _GimpPreviewClass
 {
   GtkVBoxClass  parent_class;
@@ -78,6 +71,10 @@ struct _GimpPreviewClass
                           GimpPreviewArea *area,
                           gint             width,
                           gint             height);
+  void   (* draw_buffer) (GimpPreview     *preview,
+                          const guchar    *buffer,
+                          gint             rowstride);
+  void   (* set_cursor)  (GimpPreview     *preview);
 
   /* signal */
   void   (* invalidated) (GimpPreview   *preview);
@@ -86,25 +83,29 @@ struct _GimpPreviewClass
 
 GType     gimp_preview_get_type     (void) G_GNUC_CONST;
 
-void      gimp_preview_set_update   (GimpPreview *preview,
-                                     gboolean     update);
-gboolean  gimp_preview_get_update   (GimpPreview *preview);
+void      gimp_preview_set_update   (GimpPreview  *preview,
+                                     gboolean      update);
+gboolean  gimp_preview_get_update   (GimpPreview  *preview);
 
-void      gimp_preview_set_bounds   (GimpPreview *preview,
-                                     gint         xmin,
-                                     gint         ymin,
-                                     gint         xmax,
-                                     gint         ymax);
+void      gimp_preview_set_bounds   (GimpPreview  *preview,
+                                     gint          xmin,
+                                     gint          ymin,
+                                     gint          xmax,
+                                     gint          ymax);
 
-void      gimp_preview_get_size     (GimpPreview *preview,
-                                     gint        *width,
-                                     gint        *height);
-void      gimp_preview_get_position (GimpPreview *preview,
-                                     gint        *x,
-                                     gint        *y);
+void      gimp_preview_get_position (GimpPreview  *preview,
+                                     gint         *x,
+                                     gint         *y);
+void      gimp_preview_get_size     (GimpPreview  *preview,
+                                     gint         *width,
+                                     gint         *height);
 
-void      gimp_preview_draw         (GimpPreview *preview);
-void      gimp_preview_invalidate   (GimpPreview *preview);
+void      gimp_preview_draw         (GimpPreview  *preview);
+void      gimp_preview_draw_buffer  (GimpPreview  *preview,
+                                     const guchar *buffer,
+                                     gint          rowstride);
+
+void      gimp_preview_invalidate   (GimpPreview  *preview);
 
 
 G_END_DECLS
