@@ -23,9 +23,10 @@
 #include "config.h"
 
 #include <errno.h>
-#include <sys/types.h>
-#include <sys/stat.h>
 #include <fcntl.h>
+#include <string.h>
+#include <sys/stat.h>
+#include <sys/types.h>
 
 #include <gtk/gtk.h>
 
@@ -47,7 +48,8 @@ typedef struct
 enum
 {
   PROP_0,
-  PROP_DEVICE
+  PROP_DEVICE,
+  PROP_CHANNEL
 };
 
 
@@ -66,7 +68,10 @@ struct _ControllerMidi
   GimpController  parent_instance;
 
   gchar          *device;
+  gint            midi_channel;
+
   GIOChannel     *io;
+  guint           io_id;
 
   /* midi status */
   gboolean        swallow;
@@ -108,6 +113,7 @@ static const gchar * midi_get_event_blurb (GimpController *controller,
 static gboolean      midi_set_device      (ControllerMidi *controller,
                                            const gchar    *device);
 static void          midi_event           (ControllerMidi *midi,
+                                           gint            channel,
                                            gint            event_id,
                                            gdouble         value);
 
@@ -188,11 +194,21 @@ midi_class_init (ControllerMidiClass *klass)
   object_class->set_property       = midi_set_property;
 
   g_object_class_install_property (object_class, PROP_DEVICE,
-                                   g_param_spec_string ("device", NULL, NULL,
+                                   g_param_spec_string ("device",
+                                                        _("Device:"),
+                                                        _("The name of the device to read MIDI events from."),
                                                         NULL,
                                                         G_PARAM_READWRITE |
                                                         G_PARAM_CONSTRUCT |
-                                                        GIMP_CONTROLLER_PARAM_SERIALIZE));
+                                                        GIMP_MODULE_PARAM_SERIALIZE));
+  g_object_class_install_property (object_class, PROP_CHANNEL,
+                                   g_param_spec_int ("channel",
+                                                     _("Channel:"),
+                                                     _("The MIDI channel to read events from. Set to -1 for reading from all MIDI channels."),
+                                                     -1, 15, -1,
+                                                     G_PARAM_READWRITE |
+                                                     G_PARAM_CONSTRUCT |
+                                                     GIMP_MODULE_PARAM_SERIALIZE));
 
   controller_class->name            = _("Midi Events");
 
@@ -204,16 +220,18 @@ midi_class_init (ControllerMidiClass *klass)
 static void
 midi_init (ControllerMidi *midi)
 {
-  midi->device   = NULL;
-  midi->io       = NULL;
+  midi->device       = NULL;
+  midi->midi_channel = -1;
+  midi->io           = NULL;
+  midi->io_id        = 0;
 
-  midi->swallow  = TRUE; /* get rid of data bytes at start of stream */
-  midi->command  = 0x0;
-  midi->channel  = 0x0;
-  midi->key      = -1;
-  midi->velocity = -1;
-  midi->msb      = -1;
-  midi->lsb      = -1;
+  midi->swallow      = TRUE; /* get rid of data bytes at start of stream */
+  midi->command      = 0x0;
+  midi->channel      = 0x0;
+  midi->key          = -1;
+  midi->velocity     = -1;
+  midi->msb          = -1;
+  midi->lsb          = -1;
 }
 
 static void
@@ -239,6 +257,9 @@ midi_set_property (GObject      *object,
     case PROP_DEVICE:
       midi_set_device (midi, g_value_get_string (value));
       break;
+    case PROP_CHANNEL:
+      midi->midi_channel = g_value_get_int (value);
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
       break;
@@ -258,6 +279,9 @@ midi_get_property (GObject    *object,
     case PROP_DEVICE:
       g_value_set_string (value, midi->device);
       break;
+    case PROP_CHANNEL:
+      g_value_set_int (value, midi->midi_channel);
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
       break;
@@ -334,6 +358,9 @@ midi_set_device (ControllerMidi *midi,
 
   if (midi->io)
     {
+      g_source_remove (midi->io_id);
+      midi->io_id = 0;
+
       g_io_channel_unref (midi->io);
       midi->io = NULL;
     }
@@ -343,7 +370,7 @@ midi_set_device (ControllerMidi *midi,
 
   midi->device = g_strdup (device);
 
-  if (device)
+  if (midi->device && strlen (midi->device))
     {
       gint fd;
 
@@ -355,16 +382,18 @@ midi_set_device (ControllerMidi *midi,
 
       if (fd >= 0)
         {
-          g_object_set (midi, "name", device, NULL);
+          gchar *name = g_strdup_printf (_("Reading from %s"), midi->device);
+          g_object_set (midi, "name", name, NULL);
+          g_free (name);
 
           midi->io = g_io_channel_unix_new (fd);
           g_io_channel_set_close_on_unref (midi->io, TRUE);
           g_io_channel_set_encoding (midi->io, NULL, NULL);
 
-          g_io_add_watch (midi->io,
-                          G_IO_IN,
-                          midi_read_event,
-                          midi);
+          midi->io_id = g_io_add_watch (midi->io,
+                                        G_IO_IN,
+                                        midi_read_event,
+                                        midi);
           return TRUE;
         }
       else
@@ -385,21 +414,27 @@ midi_set_device (ControllerMidi *midi,
 
 static void
 midi_event (ControllerMidi *midi,
+            gint            channel,
             gint            event_id,
             gdouble         value)
 {
-  GimpControllerEvent event = { 0, };
+  if (channel == -1            ||
+      midi->midi_channel == -1 ||
+      channel == midi->midi_channel)
+    {
+      GimpControllerEvent event = { 0, };
 
-  event.any.type     = GIMP_CONTROLLER_EVENT_VALUE;
-  event.any.source   = GIMP_CONTROLLER (midi);
-  event.any.event_id = event_id;
+      event.any.type     = GIMP_CONTROLLER_EVENT_VALUE;
+      event.any.source   = GIMP_CONTROLLER (midi);
+      event.any.event_id = event_id;
 
-  g_value_init (&event.value.value, G_TYPE_DOUBLE);
-  g_value_set_double (&event.value.value, value);
+      g_value_init (&event.value.value, G_TYPE_DOUBLE);
+      g_value_set_double (&event.value.value, value);
 
-  gimp_controller_event (GIMP_CONTROLLER (midi), &event);
+      gimp_controller_event (GIMP_CONTROLLER (midi), &event);
 
-  g_value_unset (&event.value.value);
+      g_value_unset (&event.value.value);
+    }
 }
 
 
@@ -544,24 +579,25 @@ midi_read_event (GIOChannel   *io,
 
               if (midi->command == 0x9)
                 {
-                  D (g_print ("MIDI: note on (%02x vel %02x)\n",
+                  D (g_print ("MIDI (ch %02d): note on  (%02x vel %02x)\n",
+                              midi->channel,
                               midi->key, midi->velocity));
 
-                  midi_event (midi, midi->key,
+                  midi_event (midi, midi->channel, midi->key,
                               (gdouble) midi->velocity / 127.0);
                 }
               else if (midi->command == 0x8)
                 {
-                  D (g_print ("MIDI: note off (%02x vel %02x)\n",
-                              midi->key, midi->velocity));
+                  D (g_print ("MIDI (ch %02d): note off (%02x vel %02x)\n",
+                              midi->channel, midi->key, midi->velocity));
 
-                  midi_event (midi, midi->key + 128,
+                  midi_event (midi, midi->channel, midi->key + 128,
                               (gdouble) midi->velocity / 127.0);
                 }
               else
                 {
-                  D (g_print ("MIDI: polyphonic aftertouch (%02x pressure %02x)\n",
-                              midi->key, midi->velocity));
+                  D (g_print ("MIDI (ch %02d): polyphonic aftertouch (%02x pressure %02x)\n",
+                              midi->channel, midi->key, midi->velocity));
                 }
 
               midi->key      = -1;
@@ -579,10 +615,10 @@ midi_read_event (GIOChannel   *io,
               if (midi->velocity == -1)
                 midi->velocity = buf[pos++];
 
-              D (g_print ("MIDI: controller %d (value %d)\n",
-                          midi->key, midi->velocity));
+              D (g_print ("MIDI (ch %02d): controller %d (value %d)\n",
+                          midi->channel, midi->key, midi->velocity));
 
-              midi_event (midi, midi->key + 128 + 128,
+              midi_event (midi, midi->channel, midi->key + 128 + 128,
                           (gdouble) midi->velocity / 127.0);
 
               midi->key      = -1;
@@ -592,7 +628,8 @@ midi_read_event (GIOChannel   *io,
             case 0xc:  /* program change */
               midi->key = buf[pos++];
 
-              D (g_print ("MIDI: program change (%d)\n", midi->key));
+              D (g_print ("MIDI (ch %02d): program change (%d)\n",
+                          midi->channel, midi->key));
 
               midi->key = -1;
               break;
@@ -600,7 +637,8 @@ midi_read_event (GIOChannel   *io,
             case 0xd:  /* channel key pressure */
               midi->velocity = buf[pos++];
 
-              D (g_print ("MIDI: channel aftertouch (%d)\n", midi->velocity));
+              D (g_print ("MIDI (ch %02d): channel aftertouch (%d)\n",
+                          midi->channel, midi->velocity));
 
               midi->velocity = -1;
               break;
@@ -617,7 +655,8 @@ midi_read_event (GIOChannel   *io,
 
               midi->velocity = midi->lsb | (midi->msb << 7);
 
-              D (g_print ("MIDI: pitch (%d)\n", midi->velocity));
+              D (g_print ("MIDI (ch %02d): pitch (%d)\n",
+                          midi->channel, midi->velocity));
 
               midi->msb      = -1;
               midi->lsb      = -1;
