@@ -263,7 +263,7 @@ explorer_number_of_colors_callback (GtkAdjustment *adjustment,
   g_free (gradient_samples);
 
   if (! gradient_name)
-    gradient_name = gimp_gradients_get_gradient ();
+    gradient_name = gimp_context_get_gradient ();
 
   gimp_gradients_get_gradient_data (gradient_name,
                                     wvals.ncolors,
@@ -1134,7 +1134,7 @@ explorer_dialog (void)
                            _("Create a color-map using a gradient from "
                              "the gradient editor"), NULL);
 
-  gradient_name = gimp_gradients_get_gradient ();
+  gradient_name = gimp_context_get_gradient ();
   gradient_samples = gimp_gradients_sample_uniform (wvals.ncolors,
                                                     wvals.gradinvert);
   gradient = gimp_gradient_select_widget_new (_("FractalExplorer Gradient"),
