@@ -59,8 +59,6 @@ static void        toalpha             (GimpDrawable      *drawable);
 static gboolean    colortoalpha_dialog (GimpDrawable      *drawable);
 
 
-static GimpRunMode run_mode;
-
 GimpPlugInInfo PLUG_IN_INFO =
 {
   NULL,  /* init_proc  */
@@ -119,6 +117,7 @@ run (const gchar      *name,
   GimpDrawable      *drawable;
   gint32             image_ID;
   GimpPDBStatusType  status = GIMP_PDB_SUCCESS;
+  GimpRunMode        run_mode;
 
   run_mode = param[0].data.d_int32;
 
@@ -138,7 +137,7 @@ run (const gchar      *name,
     {
     case GIMP_RUN_INTERACTIVE:
       gimp_get_data ("plug_in_colortoalpha", &pvals);
-      gimp_palette_get_foreground (&pvals.color);
+      gimp_context_get_foreground (&pvals.color);
       if (! colortoalpha_dialog (drawable))
 	{
 	  gimp_drawable_detach (drawable);
@@ -301,7 +300,7 @@ toalpha_func (const guchar *src,
 static void
 toalpha (GimpDrawable *drawable)
 {
-  gimp_rgn_iterate2 (drawable, run_mode, toalpha_func, NULL);
+  gimp_rgn_iterate2 (drawable, 0 /* unused */, toalpha_func, NULL);
 }
 
 static gboolean
