@@ -1,5 +1,5 @@
 /*
- * "$Id: despeckle.c,v 1.69 2004/09/15 19:56:01 neo Exp $"
+ * "$Id: despeckle.c,v 1.72 2004/09/29 15:33:02 neo Exp $"
  *
  *   Despeckle (adaptive median) filter for The GIMP -- an image manipulation
  *   program
@@ -721,9 +721,7 @@ preview_update (GtkWidget *widget)
 
   preview = GIMP_PREVIEW (widget);
   rgba = g_new (guchar, preview->width * preview->height * img_bpp);
-  /*
-   * Setup for filter...
-   */
+
   gimp_preview_get_position (preview, &x1, &y1);
 
   gimp_pixel_rgn_init (&src_rgn, drawable,
@@ -855,8 +853,7 @@ preview_update (GtkWidget *widget)
    * Update the screen...
    */
 
-  gimp_drawable_preview_draw_buffer (GIMP_DRAWABLE_PREVIEW (preview),
-                                     rgba, preview->width * img_bpp);
+  gimp_preview_draw_buffer (preview, rgba, preview->width * img_bpp);
   g_free (rgba);
 
   g_free (preview_src);
