@@ -215,7 +215,7 @@ run (const gchar      *name,
     }
   else
     {
-      gimp_palette_get_foreground (&grid_cfg.hcolor);
+      gimp_context_get_foreground (&grid_cfg.hcolor);
       grid_cfg.vcolor = grid_cfg.icolor = grid_cfg.hcolor;
 
       /*  Possibly retrieve data  */
@@ -482,8 +482,7 @@ grid (gint32        image_ID,
 
   if (preview)
     {
-      gimp_drawable_preview_draw_buffer (GIMP_DRAWABLE_PREVIEW (preview),
-                                         buffer, bytes * (sx2 - sx1));
+      gimp_preview_draw_buffer (preview, buffer, bytes * (sx2 - sx1));
       g_free (buffer);
     }
   else
