@@ -1729,18 +1729,19 @@ save_dialog (void)
   gboolean       run;
 
   dialog = gimp_dialog_new (_("Save as JPEG"), "jpeg",
-                         NULL, 0,
-                         gimp_standard_help_func, "file-jpeg-save",
+                            NULL, 0,
+                            gimp_standard_help_func, "file-jpeg-save",
 
-                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                         GTK_STOCK_OK,     GTK_RESPONSE_OK,
+                            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                            GTK_STOCK_OK,     GTK_RESPONSE_OK,
 
-                         NULL);
+                            NULL);
+
+  gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 
   vbox = gtk_vbox_new (FALSE, 12);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), vbox,
-                      TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), vbox, TRUE, TRUE, 0);
   gtk_widget_show (vbox);
 
   table = gtk_table_new (1, 3, FALSE);
