@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: noisify.c,v 1.58 2004/09/15 19:56:01 neo Exp $
+ * $Id: noisify.c,v 1.62 2004/09/29 15:33:02 neo Exp $
  */
 
 /*
@@ -71,12 +71,12 @@ static void     run          (const gchar      *name,
                               GimpParam       **return_vals);
 
 
-static void     noisify_func (const guchar        *src,
-                              guchar              *dest,
-                              gint                 bpp,
-                              gpointer             data);
+static void     noisify_func (const guchar     *src,
+                              guchar           *dest,
+                              gint              bpp,
+                              gpointer          data);
 
-static void     noisify      (GimpDrawablePreview *preview);
+static void     noisify      (GimpPreview      *preview);
 
 
 static gdouble  gauss                            (GRand *gr);
@@ -106,7 +106,6 @@ static NoisifyInterface noise_int =
   { NULL, NULL, NULL, NULL }
 };
 
-static GimpRunMode     run_mode;
 
 MAIN ()
 
@@ -151,6 +150,7 @@ run (const gchar      *name,
   static GimpParam   values[1];
   GimpDrawable      *drawable;
   GimpPDBStatusType  status = GIMP_PDB_SUCCESS;
+  GimpRunMode        run_mode;
 
   run_mode = param[0].data.d_int32;
 
@@ -217,7 +217,8 @@ run (const gchar      *name,
       gimp_tile_cache_ntiles (TILE_CACHE_SIZE);
 
       /*  compute the luminosity which exceeds the luminosity threshold  */
-      gimp_rgn_iterate2 (drawable, run_mode, noisify_func, gr);
+      gimp_rgn_iterate2 (drawable, 0 /* unused */, noisify_func, gr);
+
       g_rand_free (gr);
 
       if (run_mode != GIMP_RUN_NONINTERACTIVE)
@@ -271,24 +272,29 @@ noisify_func (const guchar *src,
 }
 
 static void
-noisify (GimpDrawablePreview *preview)
+noisify (GimpPreview *preview)
 {
-  guchar       *src, *dst;
+  GimpDrawable *drawable;
   GimpPixelRgn  src_rgn;
+  guchar       *src, *dst;
   gint          i;
   gint          x1, y1;
   gint          width, height;
   gint          bpp;
   GRand        *gr = g_rand_new ();
 
-  gimp_preview_get_position (GIMP_PREVIEW (preview), &x1, &y1);
-  gimp_preview_get_size (GIMP_PREVIEW (preview), &width, &height);
-  bpp = preview->drawable->bpp;
+  drawable =
+    gimp_drawable_preview_get_drawable (GIMP_DRAWABLE_PREVIEW (preview));
+
+  gimp_preview_get_position (preview, &x1, &y1);
+  gimp_preview_get_size (preview, &width, &height);
+
+  bpp = drawable->bpp;
 
   src = g_new (guchar, width * height * bpp);
   dst = g_new (guchar, width * height * bpp);
 
-  gimp_pixel_rgn_init (&src_rgn, preview->drawable,
+  gimp_pixel_rgn_init (&src_rgn, drawable,
                        x1, y1, width, height,
                        FALSE, FALSE);
   gimp_pixel_rgn_get_rect (&src_rgn, src, x1, y1, width, height);
@@ -296,7 +302,7 @@ noisify (GimpDrawablePreview *preview)
   for (i = 0; i < width * height; i++)
     noisify_func (src + i * bpp, dst + i * bpp, bpp, gr);
 
-  gimp_drawable_preview_draw_buffer (preview, dst, width * bpp);
+  gimp_preview_draw_buffer (preview, dst, width * bpp);
 
   g_free (src);
   g_free (dst);
