@@ -93,32 +93,37 @@ query (void)
                           "Francisco Bustamante & Nick Lamb",
                           "Nick Lamb <njl195@zepler.org.uk>",
                           "January 1997",
-                          "<Load>/PCX",
+                          N_("ZSoft PCX image"),
 			  NULL,
                           GIMP_PLUGIN,
                           G_N_ELEMENTS (load_args),
                           G_N_ELEMENTS (load_return_vals),
                           load_args, load_return_vals);
 
+  gimp_plugin_menu_register ("file_pcx_load", "<Load>");
+  gimp_register_file_handler_mime ("file_pcx_load", "image/x-pcx");
+  gimp_register_magic_load_handler ("file_pcx_load",
+				    "pcx,pcc",
+				    "",
+				    "0&,byte,10,2&,byte,1,3&,byte,>0,3,byte,<9");
+
   gimp_install_procedure ("file_pcx_save",
                           "Saves files in ZSoft PCX file format",
                           "FIXME: write help for pcx_save",
                           "Francisco Bustamante & Nick Lamb",
                           "Nick Lamb <njl195@zepler.org.uk>",
                           "January 1997",
-                          "<Save>/PCX",
+                          N_("ZSoft PCX image"),
 			  "INDEXED, RGB, GRAY",
                           GIMP_PLUGIN,
                           G_N_ELEMENTS (save_args), 0,
                           save_args, NULL);
 
-  gimp_register_magic_load_handler ("file_pcx_load",
-				    "pcx,pcc",
-				    "",
-				    "0&,byte,10,2&,byte,1,3&,byte,>0,3,byte,<9");
-  gimp_register_save_handler       ("file_pcx_save",
-				    "pcx,pcc",
-				    "");
+  gimp_plugin_menu_register ("file_pcx_save", "<Save>");
+  gimp_register_file_handler_mime ("file_pcx_save", "image/x-pcx");
+  gimp_register_save_handler ("file_pcx_save",
+                              "pcx,pcc",
+                              "");
 }
 
 /* Declare internal functions. */
