@@ -1,5 +1,5 @@
 /*
- * "$Id: png.c,v 1.114 2004/07/14 22:09:51 plafleur Exp $"
+ * "$Id: png.c,v 1.115 2004/09/22 18:43:08 mitch Exp $"
  *
  *   Portable Network Graphics (PNG) plug-in for The GIMP -- an image
  *   manipulation program
@@ -1277,7 +1277,7 @@ save_image (const gchar *filename,
     {
       GimpRGB color;
 
-      gimp_palette_get_background (&color);
+      gimp_context_get_background (&color);
       gimp_rgb_get_uchar (&color, &red, &green, &blue);
 
       background.index = 0;
