@@ -279,7 +279,7 @@ run (const gchar      *name,
   tile_height = gimp_tile_height ();
 
   /* get currently selected foreground pixel color */
-  gimp_palette_get_foreground (&color);
+  gimp_context_get_foreground (&color);
   gimp_rgb_get_uchar (&color,
 		      &color_pixel[0],
 		      &color_pixel[1],
