@@ -69,7 +69,7 @@
 	 )
 
     (gimp-selection-all img)
-    (gimp-palette-set-background backcolor)
+    (gimp-context-set-background backcolor)
     (gimp-edit-fill drawable1 BACKGROUND-FILL)
 
     (let* (
@@ -83,13 +83,13 @@
       (gimp-image-undo-disable temp-img)
       (gimp-image-add-layer temp-img temp-draw 0)
       (gimp-image-add-layer temp-img temp-draw2 0)
-      (gimp-palette-set-background backcolor)
+      (gimp-context-set-background backcolor)
       (gimp-edit-fill temp-draw BACKGROUND-FILL)
       (gimp-edit-fill temp-draw2 BACKGROUND-FILL)
 
       ;weird aint it
-      (gimp-palette-set-background begincolor)
-      (gimp-palette-set-foreground endcolor)
+      (gimp-context-set-background begincolor)
+      (gimp-context-set-foreground endcolor)
 
       (center-ellipse temp-img size size outer-radius outer-radius
 		      CHANNEL-OP-REPLACE TRUE FALSE 0)
@@ -168,10 +168,9 @@
 	 (tiledraw2 (car (gimp-layer-new tile size size
 					 RGB-IMAGE "Cooper" 100 NORMAL-MODE)))
 	 (Xindex 0)
-	 (Yindex 0)
-	 (old-bg (car (gimp-palette-get-background)))
-	 (old-fg (car (gimp-palette-get-foreground)))
-	 )
+	 (Yindex 0))
+
+    (gimp-context-push)
 
     (gimp-image-undo-disable img)
     (gimp-image-undo-disable tile)
@@ -182,7 +181,7 @@
  
     ;just to look a little better
     (gimp-selection-all img)
-    (gimp-palette-set-background backcolor)
+    (gimp-context-set-background backcolor)
     (gimp-edit-fill layer-one BACKGROUND-FILL)
     (gimp-selection-none img)
 
@@ -205,12 +204,10 @@
 	   )
  
     (gimp-image-delete tile)
-    (gimp-palette-set-background old-bg)
-    (gimp-palette-set-foreground old-fg)
     (gimp-image-undo-enable img)
     (gimp-display-new img)
-    )
-  )
+
+    (gimp-context-pop)))
 
 (script-fu-register "script-fu-3dtruchet"
 		    _"<Toolbox>/Xtns/Script-Fu/Patterns/3_D Truchet..."
