@@ -8,26 +8,26 @@
   (let* ((width (car (gimp-drawable-width logo-layer)))
 	 (height (car (gimp-drawable-height logo-layer)))
 	 (bg-layer (car (gimp-layer-new img width height RGBA-IMAGE "Background" 100 NORMAL-MODE)))
-	 (shadow-layer (car (gimp-layer-new img width height RGBA-IMAGE "Shadow" 100 MULTIPLY-MODE)))
-	 (old-fg (car (gimp-palette-get-foreground)))
-	 (old-bg (car (gimp-palette-get-background))))
+	 (shadow-layer (car (gimp-layer-new img width height RGBA-IMAGE "Shadow" 100 MULTIPLY-MODE))))
+
+    (gimp-context-push)
 
     (gimp-selection-none img)
     (script-fu-util-image-resize-from-layer img logo-layer)
     (gimp-image-add-layer img shadow-layer 1)
     (gimp-image-add-layer img bg-layer 2)
-    (gimp-palette-set-foreground text-color)
+    (gimp-context-set-foreground text-color)
     (gimp-layer-set-preserve-trans logo-layer TRUE)
     (gimp-edit-fill logo-layer FOREGROUND-FILL)
-    (gimp-palette-set-background bg-color)
+    (gimp-context-set-background bg-color)
     (gimp-edit-fill bg-layer BACKGROUND-FILL)
     (gimp-edit-clear shadow-layer)
     (gimp-selection-layer-alpha logo-layer)
-    (gimp-palette-set-background '(0 0 0))
+    (gimp-context-set-background '(0 0 0))
     (gimp-selection-feather img 7.5)
     (gimp-edit-fill shadow-layer BACKGROUND-FILL)
     (gimp-selection-none img)
-    (gimp-palette-set-foreground '(255 255 255))
+    (gimp-context-set-foreground '(255 255 255))
 
     (gimp-edit-blend logo-layer FG-BG-RGB-MODE MULTIPLY-MODE
 		     GRADIENT-RADIAL 100 20 REPEAT-NONE FALSE
@@ -35,8 +35,8 @@
 		     0 0 width height)
 
     (gimp-layer-translate shadow-layer 3 3)
-    (gimp-palette-set-background old-bg)
-    (gimp-palette-set-foreground old-fg)))
+
+    (gimp-context-pop)))
 
 (define (script-fu-basic1-logo-alpha img
 				     logo-layer
