@@ -21,30 +21,30 @@
 	 (posy (- (cadr (gimp-drawable-offsets logo-layer))))
 	 (bg-layer (car (gimp-layer-new img width height RGB-IMAGE "Background" 100 NORMAL-MODE)))
 	 (highlight-layer (car (gimp-layer-copy logo-layer TRUE)))
-	 (shadow-layer (car (gimp-layer-new img width height RGBA-IMAGE "Shadow" 100 MULTIPLY-MODE)))
-	 (old-fg (car (gimp-palette-get-foreground)))
-	 (old-bg (car (gimp-palette-get-background))))
+	 (shadow-layer (car (gimp-layer-new img width height RGBA-IMAGE "Shadow" 100 MULTIPLY-MODE))))
+
+    (gimp-context-push)
 
     (gimp-selection-none img)
     (script-fu-util-image-resize-from-layer img logo-layer)
     (gimp-image-add-layer img bg-layer 1)
     (gimp-image-add-layer img shadow-layer 1)
     (gimp-image-add-layer img highlight-layer 1)
-    (gimp-palette-set-foreground text-color)
+    (gimp-context-set-foreground text-color)
     (gimp-layer-set-preserve-trans logo-layer TRUE)
     (gimp-edit-fill logo-layer FOREGROUND-FILL)
     (gimp-edit-clear shadow-layer)
-    (gimp-palette-set-foreground (color-highlight text-color))
+    (gimp-context-set-foreground (color-highlight text-color))
     (gimp-layer-set-preserve-trans highlight-layer TRUE)
     (gimp-edit-fill highlight-layer FOREGROUND-FILL)
-    (gimp-palette-set-background bg-color)
+    (gimp-context-set-background bg-color)
     (gimp-drawable-fill bg-layer BACKGROUND-FILL)
     (gimp-selection-layer-alpha logo-layer)
-    (gimp-palette-set-background '(0 0 0))
+    (gimp-context-set-background '(0 0 0))
     (gimp-selection-feather img 7.5)
     (gimp-edit-fill shadow-layer BACKGROUND-FILL)
     (gimp-selection-none img)
-    (gimp-palette-set-foreground '(255 255 255))
+    (gimp-context-set-foreground '(255 255 255))
 
     (gimp-edit-blend logo-layer FG-BG-RGB-MODE MULTIPLY-MODE
 		     GRADIENT-RADIAL 100 20 REPEAT-NONE FALSE
@@ -54,8 +54,8 @@
     (gimp-layer-translate shadow-layer 3 3)
     (gimp-layer-translate highlight-layer (- posx 2) (- posy 2))
     (gimp-drawable-set-name highlight-layer "Highlight")
-    (gimp-palette-set-background old-bg)
-    (gimp-palette-set-foreground old-fg)))
+
+    (gimp-context-pop)))
 
 (define (script-fu-basic2-logo-alpha img
 				     logo-layer
