@@ -58,10 +58,7 @@
 			    padding
 			    bevel-width
 			    pressed)
-  (let* ((old-fg-color (car (gimp-palette-get-foreground)))
-	 (old-bg-color (car (gimp-palette-get-background)))
-
-	 (text-extents (gimp-text-get-extents-fontname text
+  (let* ((text-extents (gimp-text-get-extents-fontname text
 					      size
 					      PIXELS
 					      font))
@@ -82,13 +79,15 @@
 					img-width img-height RGBA-IMAGE
 					"Gradient" 100 NORMAL-MODE))))
 
+    (gimp-context-push)
+
     (gimp-image-undo-disable img)
 
     ; Create bumpmap layer
     
     (gimp-image-add-layer img bumpmap -1)
-    (gimp-palette-set-foreground '(0 0 0))
-    (gimp-palette-set-background '(255 255 255))
+    (gimp-context-set-foreground '(0 0 0))
+    (gimp-context-set-background '(255 255 255))
     (gimp-edit-fill bumpmap BACKGROUND-FILL)
 
     (gimp-rect-select img 0 0 bevel-width img-height CHANNEL-OP-REPLACE FALSE 0)
@@ -108,8 +107,8 @@
     ; Create gradient layer
 
     (gimp-image-add-layer img gradient -1)
-    (gimp-palette-set-foreground ul-color)
-    (gimp-palette-set-background lr-color)
+    (gimp-context-set-foreground ul-color)
+    (gimp-context-set-background lr-color)
 
     (gimp-edit-blend gradient FG-BG-RGB-MODE NORMAL-MODE
 		     GRADIENT-LINEAR 100 0 REPEAT-NONE FALSE
@@ -121,7 +120,7 @@
 
     ; Create text layer
 
-    (gimp-palette-set-foreground text-color)
+    (gimp-context-set-foreground text-color)
     (let ((textl (car (gimp-text-fontname
 		       img -1 0 0 text 0 TRUE size PIXELS font))))
       (gimp-layer-set-offsets textl
@@ -131,10 +130,10 @@
     ; Done
 
     (gimp-selection-none img)
-    (gimp-palette-set-foreground old-fg-color)
-    (gimp-palette-set-background old-bg-color)
     (gimp-image-undo-enable img)
-    (gimp-display-new img)))
+    (gimp-display-new img)
+
+    (gimp-context-pop)))
 
 (script-fu-register "script-fu-button00"
 		    _"<Toolbox>/Xtns/Script-Fu/Buttons/Simple _Beveled Button..."
