@@ -39,9 +39,7 @@
 
 (define (script-fu-beveled-pattern-button
 	 text text-size font text-color pattern pressed)
-  (let* ((old-bg-color (car (gimp-palette-get-background)))
-
-	 (text-extents (gimp-text-get-extents-fontname
+  (let* ((text-extents (gimp-text-get-extents-fontname
 			text text-size PIXELS font))
 	 (ascent (text-ascent text-extents))
 	 (descent (text-descent text-extents))
@@ -61,26 +59,28 @@
 		 (gimp-text-fontname
 		  img -1 0 0 text 0 TRUE text-size PIXELS font))))
 
+    (gimp-context-push)
+
     (gimp-image-undo-disable img)
     (gimp-image-add-layer img background 1)
     (gimp-image-add-layer img bumpmap 1)
 
     ; Create pattern layer
 
-    (gimp-palette-set-background '(0 0 0))
+    (gimp-context-set-background '(0 0 0))
     (gimp-edit-fill background BACKGROUND-FILL)
-    (gimp-patterns-set-pattern pattern)
+    (gimp-context-set-pattern pattern)
     (gimp-edit-bucket-fill background PATTERN-BUCKET-FILL NORMAL-MODE 100 0 FALSE 0 0)
 
     ; Create bumpmap layer
 
     (gimp-edit-fill bumpmap BACKGROUND-FILL)
 
-    (gimp-palette-set-background '(127 127 127))
+    (gimp-context-set-background '(127 127 127))
     (gimp-rect-select img 1 1 (- width 2) (- height 2) CHANNEL-OP-REPLACE FALSE 0)
     (gimp-edit-fill bumpmap BACKGROUND-FILL)
 
-    (gimp-palette-set-background '(255 255 255))
+    (gimp-context-set-background '(255 255 255))
     (gimp-rect-select img 2 2 (- width 4) (- height 4) CHANNEL-OP-REPLACE FALSE 0)
     (gimp-edit-fill bumpmap BACKGROUND-FILL)
 
@@ -92,7 +92,7 @@
 
     ; Color and position text
 
-    (gimp-palette-set-background text-color)
+    (gimp-context-set-background text-color)
     (gimp-layer-set-preserve-trans textl TRUE)
     (gimp-edit-fill textl BACKGROUND-FILL)
 
@@ -106,9 +106,10 @@
     (gimp-image-remove-layer img bumpmap)
     (gimp-image-flatten img)
 
-    (gimp-palette-set-background old-bg-color)
     (gimp-image-undo-enable img)
-    (gimp-display-new img)))
+    (gimp-display-new img)
+
+    (gimp-context-pop)))
 
 
 (script-fu-register "script-fu-beveled-pattern-button"
