@@ -21,30 +21,36 @@
 
 
 (define (script-fu-beveled-pattern-hrule width height pattern)
-  (let* ((old-bg-color (car (gimp-palette-get-background)))
-	 (img (car (gimp-image-new width height RGB)))
-	 (background (car (gimp-layer-new img width height RGB-IMAGE "Hrule" 100 NORMAL-MODE)))
-	 (bumpmap (car (gimp-layer-new img width height RGBA-IMAGE "Bumpmap" 100 NORMAL-MODE))))
+  (let* ((img (car (gimp-image-new width height RGB)))
+	 (background (car (gimp-layer-new img
+					  width height RGB-IMAGE
+					  "Hrule" 100 NORMAL-MODE)))
+	 (bumpmap (car (gimp-layer-new img
+				       width height RGBA-IMAGE
+				       "Bumpmap" 100 NORMAL-MODE))))
+
+    (gimp-context-push)
+
     (gimp-image-undo-disable img)
     (gimp-image-add-layer img background -1)
     (gimp-image-add-layer img bumpmap -1)
 
     ; Create pattern layer
 
-    (gimp-palette-set-background '(0 0 0))
+    (gimp-context-set-background '(0 0 0))
     (gimp-edit-fill background BACKGROUND-FILL)
-    (gimp-patterns-set-pattern pattern)
+    (gimp-context-set-pattern pattern)
     (gimp-edit-bucket-fill background PATTERN-BUCKET-FILL NORMAL-MODE 100 0 FALSE 0 0)
 
     ; Create bumpmap layer
 
     (gimp-edit-fill bumpmap BACKGROUND-FILL)
 
-    (gimp-palette-set-background '(127 127 127))
+    (gimp-context-set-background '(127 127 127))
     (gimp-rect-select img 1 1 (- width 2) (- height 2) CHANNEL-OP-REPLACE FALSE 0)
     (gimp-edit-fill bumpmap BACKGROUND-FILL)
 
-    (gimp-palette-set-background '(255 255 255))
+    (gimp-context-set-background '(255 255 255))
     (gimp-rect-select img 2 2 (- width 4) (- height 4) CHANNEL-OP-REPLACE FALSE 0)
     (gimp-edit-fill bumpmap BACKGROUND-FILL)
 
@@ -57,9 +63,10 @@
     (gimp-image-set-active-layer img background)
     (gimp-image-remove-layer img bumpmap)
 
-    (gimp-palette-set-background old-bg-color)
     (gimp-image-undo-enable img)
-    (gimp-display-new img)))
+    (gimp-display-new img)
+
+    (gimp-context-pop)))
 
 
 (script-fu-register "script-fu-beveled-pattern-hrule"
