@@ -25,9 +25,7 @@
   (let* (
 	 ;--- main variable: "bl-x" runs from 0 to layer-width
 	 (bl-x 0)
-	 (frame-nr 0)
-	 (old-fg (car (gimp-palette-get-foreground)))
-	 (old-bg (car (gimp-palette-get-background))))
+	 (frame-nr 0))
 
     (if (< speed 1)
 	(set! speed (* -1 speed)) )
@@ -37,6 +35,8 @@
 
         ;--- main program structure starts here, begin of "if-1"
 	(begin
+	  (gimp-context-push)
+
 	  (set! img (car (gimp-image-duplicate org-img)))
 	  (gimp-image-undo-disable img)
 	  (if (> (car (gimp-drawable-type org-layer)) 1 )
@@ -88,8 +88,8 @@
 					 CHANNEL-OP-REPLACE 0 0)))
 
                  ;--- alpha blending text to trans (fadeout)
-		 (gimp-palette-set-foreground '(255 255 255))
-		 (gimp-palette-set-background '(  0   0   0))
+		 (gimp-context-set-foreground '(255 255 255))
+		 (gimp-context-set-background '(  0   0   0))
 		 (if (= fadeout TRUE)
 		     (begin
                        ; blend with 20% offset to get less transparency in the front
@@ -100,7 +100,7 @@
 
 		 (if (= fadeout FALSE)
 		     (begin
-		       (gimp-palette-set-foreground '(255 255 255))
+		       (gimp-context-set-foreground '(255 255 255))
 		       (gimp-edit-bucket-fill bl-mask FG-BUCKET-FILL NORMAL-MODE
                                               100 255 0 0 0)))
 
@@ -114,7 +114,7 @@
 			   (gimp-brightness-contrast bl-layer 100 0))
 
                      ;--- blend glow color inside the letters
-		     (gimp-palette-set-foreground glow-color)
+		     (gimp-context-set-foreground glow-color)
 		     (gimp-edit-blend bl-layer FG-TRANSPARENT-MODE NORMAL-MODE
 				      GRADIENT-LINEAR 100 0 REPEAT-NONE FALSE
 				      FALSE 0 0 TRUE
@@ -127,7 +127,7 @@
 		     (gimp-selection-grow img corona-width)
 		     (gimp-layer-set-preserve-trans bl-layer FALSE)
 		     (gimp-selection-feather img corona-width)
-		     (gimp-palette-set-foreground glow-color)
+		     (gimp-context-set-foreground glow-color)
 		     (gimp-edit-blend bl-layer FG-TRANSPARENT-MODE NORMAL-MODE
 				      GRADIENT-LINEAR 100 0 REPEAT-NONE FALSE
 				      FALSE 0 0 TRUE
@@ -171,10 +171,10 @@
 	  (gimp-image-undo-enable img)
 	  (gimp-image-clean-all img)
 	  (set! img-display (car (gimp-display-new img)))
-	  (gimp-palette-set-foreground old-fg)
-	  (gimp-palette-set-background old-bg)
 
-	  (gimp-displays-flush))
+	  (gimp-displays-flush)
+
+	  (gimp-context-pop))
 
 	;--- false form of "if-1"
 	(gimp-message _"Burn-In: Need two layers in total!"
