@@ -21,12 +21,16 @@
 
 (define (script-fu-camo-pattern inSize inGrain inColor1 inColor2 inColor3 inSmooth inFlatten)
 
-        (set! old-bg (car (gimp-palette-get-background)))
-        (set! theWidth inSize)
-	(set! theHeight inSize)
-        (set! theImage (car(gimp-image-new theWidth theHeight RGB)))
+  (let* (
+        (theWidth inSize)
+        (theHeight inSize)
+        (theImage (car (gimp-image-new theWidth theHeight RGB)))
+        (baseLayer (car (gimp-layer-new theImage theWidth theHeight RGBA-IMAGE "Background" 100 NORMAL-MODE)))
+        (thickLayer)
+        (thinLayer)
+        (theBlur)
+        )
 
-        (set! baseLayer (car (gimp-layer-new theImage theWidth theHeight RGBA-IMAGE "Background" 100 NORMAL-MODE)))
         (gimp-image-add-layer theImage baseLayer 0)
 
         (set! thickLayer (car (gimp-layer-new theImage theWidth theHeight RGBA-IMAGE "Camo Thick Layer" 100 NORMAL-MODE)))
@@ -35,8 +39,10 @@
         (set! thinLayer (car (gimp-layer-new theImage theWidth theHeight RGBA-IMAGE "Camo Thin Layer" 100 NORMAL-MODE)))
         (gimp-image-add-layer theImage thinLayer 0)
 
+	(gimp-context-push)
+
         (gimp-selection-all theImage)
-        (gimp-palette-set-background inColor1)
+        (gimp-context-set-background inColor1)
         (gimp-drawable-fill baseLayer BACKGROUND-FILL)
 
         (plug-in-solid-noise TRUE theImage thickLayer 1 0 (rand 65536) 1 inGrain inGrain)
@@ -46,7 +52,7 @@
 
 	(set! theBlur (- 16 inGrain))
 
-        (gimp-palette-set-background inColor2)
+        (gimp-context-set-background inColor2)
         (gimp-by-color-select thickLayer '(0 0 0) 127 CHANNEL-OP-REPLACE  TRUE FALSE 0 FALSE)
         (gimp-edit-clear thickLayer)
         (gimp-selection-invert theImage)
@@ -58,7 +64,7 @@
         )
 
 
-        (gimp-palette-set-background inColor3)
+        (gimp-context-set-background inColor3)
         (gimp-by-color-select thinLayer '(0 0 0) 127 CHANNEL-OP-REPLACE  TRUE FALSE 0 FALSE)
         (gimp-edit-clear thinLayer)
         (gimp-selection-invert theImage)
@@ -73,11 +79,11 @@
         (if (= inFlatten TRUE)
             (gimp-image-flatten theImage)
             ()
-        )
-        (gimp-palette-set-background old-bg)
-        (gimp-display-new theImage)
-)
+	)
 
+        (gimp-display-new theImage)
+
+	(gimp-context-pop)))
 
 
 ; Register the function with the GIMP:
