@@ -46,18 +46,18 @@
 	 (cast-shadow-layer 0)
 	 (csl-mask 0)
 	 (inset-layer 0)
-	 (il-mask 0)
-	 (old-fg (car (gimp-palette-get-foreground)))
-	 (old-bg (car (gimp-palette-get-background)))
-	 (old-brush (car (gimp-brushes-get-brush))))
+	 (il-mask 0))
+
+    (gimp-context-push)
+
     (gimp-image-undo-disable img)
 
     (gimp-image-set-filename img "")
 
     (gimp-layer-set-preserve-trans mask-layer TRUE)
-    (gimp-palette-set-background '(255 255 255))
+    (gimp-context-set-background '(255 255 255))
     (gimp-edit-fill mask-layer BACKGROUND-FILL)
-    (gimp-palette-set-background '(0 0 0))
+    (gimp-context-set-background '(0 0 0))
     (gimp-edit-fill mask BACKGROUND-FILL)
 
     (plug-in-tile 1 img layer1 width height FALSE)
@@ -74,8 +74,8 @@
     (set! mask-fat (car (gimp-channel-copy mask)))
     (gimp-image-add-channel img mask-fat 0)
     (gimp-selection-load mask-fat)
-    (gimp-brushes-set-brush (carve-brush brush-size))
-    (gimp-palette-set-foreground '(255 255 255))
+    (gimp-context-set-brush (carve-brush brush-size))
+    (gimp-context-set-foreground '(255 255 255))
     (gimp-edit-stroke mask-fat)
     (gimp-selection-none img)
 
@@ -84,7 +84,7 @@
     (plug-in-gauss-rle 1 img mask-emboss feather TRUE TRUE)
     (plug-in-emboss 1 img mask-emboss 315.0 45.0 7 TRUE)
 
-    (gimp-palette-set-background '(180 180 180))
+    (gimp-context-set-background '(180 180 180))
     (gimp-selection-load mask-fat)
     (gimp-selection-invert img)
     (gimp-edit-fill mask-emboss BACKGROUND-FILL)
@@ -120,7 +120,7 @@
     (set! csl-mask (car (gimp-layer-create-mask cast-shadow-layer ADD-BLACK-MASK)))
     (gimp-layer-add-mask cast-shadow-layer csl-mask)
     (gimp-selection-load mask)
-    (gimp-palette-set-background '(255 255 255))
+    (gimp-context-set-background '(255 255 255))
     (gimp-edit-fill csl-mask BACKGROUND-FILL)
 
     (set! inset-layer (car (gimp-layer-copy layer1 TRUE)))
@@ -129,7 +129,7 @@
     (set! il-mask (car (gimp-layer-create-mask inset-layer ADD-BLACK-MASK)))
     (gimp-layer-add-mask inset-layer il-mask)
     (gimp-selection-load mask)
-    (gimp-palette-set-background '(255 255 255))
+    (gimp-context-set-background '(255 255 255))
     (gimp-edit-fill il-mask BACKGROUND-FILL)
     (gimp-selection-none img)
 
@@ -146,11 +146,10 @@
     (gimp-drawable-set-name cast-shadow-layer "Cast Shadow")
     (gimp-drawable-set-name inset-layer "Inset")
 
-    (gimp-palette-set-foreground old-fg)
-    (gimp-palette-set-background old-bg)
-    (gimp-brushes-set-brush old-brush)
     (gimp-display-new img)
-    (gimp-image-undo-enable img)))
+    (gimp-image-undo-enable img)
+
+    (gimp-context-pop)))
 
 (script-fu-register "script-fu-carved-logo"
 		    _"<Toolbox>/Xtns/Script-Fu/Logos/Carved..."
@@ -164,7 +163,7 @@
 		    SF-FONT       _"Font" "Engraver"
 		    SF-FILENAME   _"Background Image"
 		                  (string-append ""
-						 gimp-data-dir
+						 gimp-data-directory
 						 "/scripts/images/texture3.jpg")
 		    SF-TOGGLE     _"Carve raised text" FALSE
 		    SF-ADJUSTMENT _"Padding around text" '(10 0 1000 1 10 0 1))
