@@ -85,11 +85,10 @@
 	 (layer3 (car (gimp-layer-new img width height GRAYA-IMAGE "Layer 3" 100 NORMAL-MODE)))
 	 (shadow (car (gimp-layer-new img width height GRAYA-IMAGE "Drop Shadow" 100 NORMAL-MODE)))
 	 (mask-fs 0)
-	 (layer-mask 0)
-	 (old-fg (car (gimp-palette-get-foreground)))
-	 (old-bg (car (gimp-palette-get-background)))
-	 (old-brush (car (gimp-brushes-get-brush)))
-	 (old-pattern (car (gimp-patterns-get-pattern))))
+	 (layer-mask 0))
+
+    (gimp-context-push)
+
     (gimp-image-undo-disable img)
 
     (gimp-image-add-channel img mask 0)
@@ -104,7 +103,7 @@
     (if (= carve-white FALSE)
 	(gimp-invert mask))
 
-    (gimp-palette-set-background '(255 255 255))
+    (gimp-context-set-background '(255 255 255))
     (gimp-selection-none img)
     (gimp-edit-fill layer2 BACKGROUND-FILL)
     (gimp-edit-fill layer3 BACKGROUND-FILL)
@@ -114,7 +113,7 @@
     (gimp-drawable-set-visible shadow FALSE)
 
     (gimp-selection-load mask)
-    (gimp-palette-set-background '(0 0 0))
+    (gimp-context-set-background '(0 0 0))
     (gimp-selection-translate img offx1 offy1)
     (gimp-selection-feather img feather)
     (gimp-edit-fill layer2 BACKGROUND-FILL)
@@ -136,22 +135,22 @@
     (set! layer-mask (car (gimp-layer-create-mask layer1 ADD-BLACK-MASK)))
     (gimp-layer-add-mask layer1 layer-mask)
     (gimp-selection-load mask)
-    (gimp-palette-set-background '(255 255 255))
+    (gimp-context-set-background '(255 255 255))
     (gimp-edit-fill layer-mask BACKGROUND-FILL)
 
     (set! layer2 (car (gimp-layer-copy layer1 TRUE)))
     (gimp-image-add-layer img layer2 0)
-    (gimp-brushes-set-brush (brush brush-size))
-    (gimp-palette-set-foreground '(255 255 255))
+    (gimp-context-set-brush (brush brush-size))
+    (gimp-context-set-foreground '(255 255 255))
     (gimp-edit-stroke layer-mask)
 
-    (gimp-palette-set-background '(0 0 0))
+    (gimp-context-set-background '(0 0 0))
     (gimp-selection-feather img (* feather 1.5))
     (gimp-selection-translate img (* 2.5 offx1) (* 2.5 offy1))
     (gimp-edit-fill shadow BACKGROUND-FILL)
 
     (gimp-selection-all img)
-    (gimp-patterns-set-pattern "Marble #1")
+    (gimp-context-set-pattern "Marble #1")
     (gimp-edit-bucket-fill bg-layer PATTERN-BUCKET-FILL NORMAL-MODE 100 0 FALSE 0 0)
     (gimp-selection-none img)
 
@@ -174,12 +173,10 @@
 
     (gimp-image-remove-channel img mask)
 
-    (gimp-palette-set-foreground old-fg)
-    (gimp-palette-set-background old-bg)
-    (gimp-brushes-set-brush old-brush)
-    (gimp-patterns-set-pattern old-pattern)
     (gimp-display-new img)
-    (gimp-image-undo-enable img)))
+    (gimp-image-undo-enable img)
+
+    (gimp-context-pop)))
 
 (script-fu-register "script-fu-sota-chrome-it"
 		    _"<Image>/Script-Fu/Stencil Ops/C_hrome-It..."
@@ -195,7 +192,7 @@
 		    SF-ADJUSTMENT _"Chrome factor" '(.75 0 1 .1 .01 2 0)
 		    SF-FILENAME _"Environment map"
 		                (string-append ""
-					       gimp-data-dir
+					       gimp-data-directory
 					       "/scripts/images/beavis.jpg")
 		    SF-COLOR _"Highlight balance" '(211 95 0)
 		    SF-COLOR _"Chrome balance" '(0 0 0)
