@@ -21,13 +21,14 @@
 				inNumber
 				inDark)
 
-   (set! old-gradient (car (gimp-gradients-get-gradient)))
    (set! theImage inImage)
    (set! theHeight (car (gimp-image-height theImage)))
    (set! theWidth (car (gimp-image-width theImage)))
    (set! theNumber inNumber)
    (set! theSize (min theWidth theHeight))
 
+   (gimp-context-push)
+
    (gimp-image-undo-group-start theImage)
 
    (while (> theNumber 0)
@@ -51,7 +52,7 @@
 					(* (+ (rand 15) 1) (+ (rand 15) 1))
 					(/ theSize 25) 4 2 TRUE TRUE)
 
-	  (gimp-gradients-set-gradient "Coffee")
+	  (gimp-context-set-gradient "Coffee")
 
 	  (gimp-edit-blend theStain CUSTOM-MODE NORMAL-MODE
 			   GRADIENT-SHAPEBURST-DIMPLED 100 0 REPEAT-NONE FALSE
@@ -66,8 +67,9 @@
 
    (gimp-image-undo-group-end theImage)
 
-   (gimp-gradients-set-gradient old-gradient)
-   (gimp-displays-flush))
+   (gimp-displays-flush)
+
+   (gimp-context-pop))
 
 ; Register the function with the GIMP:
 
