@@ -92,23 +92,23 @@
 	 (layer3 (car (gimp-layer-new img width height GRAYA-IMAGE "Layer 3" 100 NORMAL-MODE)))
 	 (layer-mask 0)
 	 (layer-mask2 0)
-	 (disp-map 0)
-	 (old-fg (car (gimp-palette-get-foreground)))
-	 (old-bg (car (gimp-palette-get-background)))
-	 (old-brush (car (gimp-brushes-get-brush))))
+	 (disp-map 0))
+
+    (gimp-context-push)
+
     (gimp-image-delete back-img)
     (gimp-image-undo-disable img)
     (gimp-image-resize img width height 0 0)
     (gimp-image-add-layer img layer3 0)
     (gimp-image-add-layer img layer2 0)
-    (gimp-palette-set-background '(255 255 255))
+    (gimp-context-set-background '(255 255 255))
     (gimp-selection-none img)
     (gimp-edit-fill layer2 BACKGROUND-FILL)
     (gimp-edit-fill layer3 BACKGROUND-FILL)
     (gimp-drawable-set-visible text-layer FALSE)
 
     (gimp-selection-layer-alpha text-layer)
-    (gimp-palette-set-background '(0 0 0))
+    (gimp-context-set-background '(0 0 0))
     (gimp-selection-translate img offx1 offy1)
     (gimp-selection-feather img feather)
     (gimp-edit-fill layer2 BACKGROUND-FILL)
@@ -130,12 +130,12 @@
     (set! layer-mask (car (gimp-layer-create-mask layer1 ADD-BLACK-MASK)))
     (gimp-layer-add-mask layer1 layer-mask)
     (gimp-selection-layer-alpha text-layer)
-    (gimp-palette-set-background '(255 255 255))
+    (gimp-context-set-background '(255 255 255))
     (gimp-edit-fill layer-mask BACKGROUND-FILL)
 
     (set! disp-map (car (gimp-selection-save img)))
-    (gimp-brushes-set-brush (crystal-brush brush-size))
-    (gimp-palette-set-foreground '(0 0 0))
+    (gimp-context-set-brush (crystal-brush brush-size))
+    (gimp-context-set-foreground '(0 0 0))
     (gimp-edit-stroke disp-map)
     (gimp-selection-none img)
 
@@ -157,7 +157,7 @@
     (set! layer-mask2 (car (gimp-layer-create-mask layer2 ADD-BLACK-MASK)))
     (gimp-layer-add-mask layer2 layer-mask2)
     (gimp-selection-layer-alpha text-layer)
-    (gimp-palette-set-background '(255 255 255))
+    (gimp-context-set-background '(255 255 255))
     (gimp-edit-fill layer-mask2 BACKGROUND-FILL)
 
     (gimp-selection-none img)
@@ -166,7 +166,7 @@
 
     (plug-in-gauss-rle 1 img text-layer blur TRUE TRUE)
     (gimp-layer-set-preserve-trans text-layer TRUE)
-    (gimp-palette-set-background '(0 0 0))
+    (gimp-context-set-background '(0 0 0))
     (gimp-edit-fill text-layer BACKGROUND-FILL)
     (gimp-layer-set-mode text-layer OVERLAY-MODE)
     (gimp-layer-translate text-layer offx1 offy1)
@@ -179,11 +179,10 @@
     (gimp-drawable-set-name bg-layer "Background")
     (gimp-drawable-set-name text-layer "Shadow")
 
-    (gimp-palette-set-foreground old-fg)
-    (gimp-palette-set-background old-bg)
-    (gimp-brushes-set-brush old-brush)
     (gimp-image-undo-enable img)
-    (gimp-display-new img)))
+    (gimp-display-new img)
+
+    (gimp-context-pop)))
 
 
 (script-fu-register "script-fu-crystal-logo"
@@ -199,9 +198,9 @@
 		    SF-FONT   _"Font" "Engraver"
 		    SF-FILENAME _"Background image"
 		                (string-append ""
-					       gimp-data-dir
+					       gimp-data-directory
 					       "/scripts/images/texture1.jpg")
 		    SF-FILENAME _"Environment map"
 		                (string-append ""
-					       gimp-data-dir
+					       gimp-data-directory
 					       "/scripts/images/beavis.jpg"))
