@@ -64,16 +64,16 @@
 							   GRAY RGB))))
 	 (drawable   (car (gimp-layer-new img width height (if (= colors 0)
 							       GRAY-IMAGE RGB-IMAGE)
-					  "Background" 100 NORMAL-MODE)))
-	 (old-bg (car (gimp-palette-get-background)))
-	 (old-fg (car (gimp-palette-get-foreground)))) 
+					  "Background" 100 NORMAL-MODE)))) 
+
+    (gimp-context-push)
 
     (gimp-image-undo-disable img)
 
     (if (= colors 0)
 	(begin
-	  (gimp-palette-set-background '(255 255 255))
-	  (gimp-palette-set-foreground '(0 0 0))))
+	  (gimp-context-set-background '(255 255 255))
+	  (gimp-context-set-foreground '(0 0 0))))
 
     (gimp-edit-clear drawable)
     (gimp-image-add-layer img drawable 0)
@@ -121,13 +121,10 @@
 
     (gimp-image-set-active-layer img drawable)
 
-    (if (= colors 0)
-	(begin
-	  (gimp-palette-set-background old-bg)
-	  (gimp-palette-set-foreground old-fg)))
-
     (gimp-image-undo-enable img)
-    (gimp-display-new img)))
+    (gimp-display-new img)
+
+    (gimp-context-pop)))
 
 (script-fu-register "script-fu-font-map"
 		    _"<Toolbox>/Xtns/Script-Fu/Utils/_Font Map..."
