@@ -14,11 +14,10 @@
 	 (matte-layer (car (gimp-layer-new img width height RGBA-IMAGE "Matte" 100 NORMAL-MODE)))
 	 (shadow-layer (car (gimp-layer-new img width height RGBA-IMAGE "Shadow" 90 MULTIPLY-MODE)))
 	 (bg-layer (car (gimp-layer-new img width height RGB-IMAGE "Background" 100 NORMAL-MODE)))
-	 (selection 0)
-	 (old-fg (car (gimp-palette-get-foreground)))
-	 (old-bg (car (gimp-palette-get-background)))
-	 (old-brush (car (gimp-brushes-get-brush)))
-	 (old-paint-mode (car (gimp-brushes-get-paint-mode))))
+	 (selection 0))
+
+    (gimp-context-push)
+
     (gimp-layer-add-mask logo-layer logo-layer-mask)
     (script-fu-util-image-resize-from-layer img logo-layer)
     (gimp-image-add-layer img sparkle-layer 2)
@@ -32,7 +31,7 @@
     (gimp-selection-layer-alpha logo-layer)
     (set! selection (car (gimp-selection-save img)))
     (gimp-selection-feather img border)
-    (gimp-palette-set-background '(0 0 0))
+    (gimp-context-set-background '(0 0 0))
     (gimp-edit-fill sparkle-layer BACKGROUND-FILL)
     (plug-in-noisify 1 img sparkle-layer FALSE 0.2 0.2 0.2 0.0)
     (plug-in-c-astretch 1 img sparkle-layer)
@@ -41,36 +40,34 @@
     (gimp-levels sparkle-layer 1 0 255 0.2 0 255)
     (gimp-levels sparkle-layer 2 0 255 0.7 0 255)
     (gimp-selection-layer-alpha sparkle-layer)
-    (gimp-palette-set-foreground '(0 0 0))
-    (gimp-brushes-set-brush "Circle Fuzzy (11)")
+    (gimp-context-set-foreground '(0 0 0))
+    (gimp-context-set-brush "Circle Fuzzy (11)")
     (gimp-edit-stroke matte-layer)
     (gimp-selection-feather img border)
     (gimp-edit-fill shadow-layer BACKGROUND-FILL)
     (gimp-selection-none img)
-    (gimp-palette-set-background bg-color)
+    (gimp-context-set-background bg-color)
     (gimp-edit-fill bg-layer BACKGROUND-FILL)
-    (gimp-palette-set-background '(0 0 0))
+    (gimp-context-set-background '(0 0 0))
     (gimp-edit-fill logo-layer BACKGROUND-FILL)
 ;    (gimp-layer-add-mask logo-layer logo-layer-mask)
     (gimp-selection-load selection)
-    (gimp-palette-set-background '(255 255 255))
+    (gimp-context-set-background '(255 255 255))
     (gimp-edit-fill logo-layer-mask BACKGROUND-FILL)
     (gimp-selection-feather img border)
     (gimp-selection-translate img (/ border 2) (/ border 2))
     (gimp-edit-fill logo-layer BACKGROUND-FILL)
     (gimp-layer-remove-mask logo-layer 0)
     (gimp-selection-load selection)
-    (gimp-brushes-set-brush "Circle Fuzzy (07)")
-    (gimp-brushes-set-paint-mode BEHIND-MODE)
-    (gimp-palette-set-foreground '(186 241 255))
+    (gimp-context-set-brush "Circle Fuzzy (07)")
+    (gimp-context-set-paint-mode BEHIND-MODE)
+    (gimp-context-set-foreground '(186 241 255))
     (gimp-edit-stroke logo-layer)
     (gimp-selection-none img)
     (gimp-image-remove-channel img selection)
     (gimp-layer-translate shadow-layer border border)
-    (gimp-palette-set-foreground old-fg)
-    (gimp-palette-set-background old-bg)
-    (gimp-brushes-set-brush old-brush)
-    (gimp-brushes-set-paint-mode old-paint-mode)))
+
+    (gimp-context-pop)))
 
 (define (script-fu-frosty-logo-alpha img
 				     logo-layer
