@@ -126,7 +126,7 @@
 		  #f))))))
 
   (define (draw-segment img drawable segment limit rgb)
-    (gimp-palette-set-foreground rgb)
+    (gimp-context-set-foreground rgb)
     (gimp-airbrush drawable 100 (* 2 limit) (segment-strokes segment)))
 
   (define red-color '(255 10 10))
@@ -143,13 +143,13 @@
   (define (fill-dot img drawable x y segment color)
     (if (fill-segment! segment x y)
 	(begin
-	  (gimp-palette-set-foreground color)
+	  (gimp-context-set-foreground color)
 	  (draw-segment img drawable segment (segment-max-size segment) color)
 	  #t)
 	#f))
 
   (define (fill-color-band img drawable x scale x-base y-base color)
-    (gimp-palette-set-foreground color)
+    (gimp-context-set-foreground color)
     (gimp-rect-select img (+ x-base (* scale x)) 0 scale y-base CHANNEL-OP-REPLACE FALSE 0)
     (gimp-edit-bucket-fill drawable FG-BUCKET-FILL NORMAL-MODE 100 0 FALSE 0 0)
     (gimp-selection-none img))
@@ -249,16 +249,14 @@
 	 (hsv '(254 255 255))
 	 (x-base border-size)
 	 (y-base (+ gimg-height border-size))
-	 (index 0)
-	 (old-foreground (car (gimp-palette-get-foreground)))
-	 (old-background (car (gimp-palette-get-background)))
-	 (old-paint-mode (car (gimp-brushes-get-paint-mode)))
-	 (old-brush (car (gimp-brushes-get-brush)))
-	 (old-opacity (car (gimp-brushes-get-opacity))))
+	 (index 0))
+
+    (gimp-context-push)
+
     (gimp-image-undo-disable gimg)
     (gimp-image-add-layer gimg bglayer -1)
     (gimp-selection-all gimg)
-    (gimp-palette-set-background '(255 255 255))
+    (gimp-context-set-background '(255 255 255))
     (gimp-edit-fill bglayer BACKGROUND-FILL)
     (gimp-image-add-layer gimg hsv-layer -1)
     (gimp-edit-clear hsv-layer)
@@ -275,9 +273,9 @@
     (set! hue-segment (make-segment 64 x-base y-base))
     (set! saturation-segment (make-segment 64 x-base y-base))
     (set! value-segment (make-segment 64 x-base y-base))
-    (gimp-brushes-set-brush "Circle (01)")
-    (gimp-brushes-set-paint-mode NORMAL-MODE)
-    (gimp-brushes-set-opacity 70)
+    (gimp-context-set-brush "Circle (01)")
+    (gimp-context-set-paint-mode NORMAL-MODE)
+    (gimp-context-set-opacity 70)
     (gimp-display-new gimg)
     (while (< index limit)
       (set! rgb (car (gimp-image-pick-color img drawable
@@ -293,7 +291,7 @@
      (lambda (segment color)
        (if (< 1 (segment-filled-size segment))
 	(begin
-	  (gimp-palette-set-foreground color)
+	  (gimp-context-set-foreground color)
 	  (draw-segment gimg hsv-layer segment (segment-filled-size segment)
 			color))))
      (list hue-segment saturation-segment value-segment)
@@ -302,29 +300,24 @@
      (lambda (segment color)
        (if (< 1 (segment-filled-size segment))
 	(begin
-	  (gimp-palette-set-foreground color)
+	  (gimp-context-set-foreground color)
 	  (draw-segment gimg rgb-layer segment (segment-filled-size segment)
 			color))))
      (list red-segment green-segment blue-segment)
      (list red-color green-color blue-color))
-    (gimp-palette-set-foreground '(255 255 255))
+    (gimp-context-set-foreground '(255 255 255))
     (let ((text-layer (car (gimp-text-fontname gimg -1 0 0
 				      "Red: Hue, Green: Sat, Blue: Val"
 				      1 1 12 PIXELS
-				      "-*-helvetica-*-r-*-*-12-*-*-*-p-*-*-*")))
+				      "Sans")))
 	  (offset-y (- y-base (car (gimp-drawable-height clayer)))))
       (gimp-layer-set-mode text-layer DIFFERENCE-MODE)
       (gimp-layer-translate clayer 0 offset-y)
       (gimp-layer-translate text-layer border-size (+ offset-y 15)))
     (gimp-image-set-active-layer gimg bglayer)
     (gimp-image-clean-all gimg)
-    ;; return back the state
-    (gimp-palette-set-foreground old-foreground)
-    (gimp-palette-set-foreground old-background)
-    (gimp-brushes-set-brush old-brush)
-    (gimp-brushes-set-paint-mode old-paint-mode)
-    (gimp-brushes-set-opacity old-opacity)
     (gimp-image-undo-enable gimg)
+
     (set! script-fu-hsv-graph-scale scale)
     (set! script-fu-hsv-graph-opacity opacity)
     (set! script-fu-hsv-graph-bounds? bounds?)
@@ -333,7 +326,9 @@
     (set! script-fu-hsv-graph-beg-y beg-y)
     (set! script-fu-hsv-graph-end-x end-x)
     (set! script-fu-hsv-graph-end-y end-y)
-    (gimp-displays-flush)))
+    (gimp-displays-flush)
+
+    (gimp-context-pop)))
 
 (script-fu-register
  "script-fu-hsv-graph"
