@@ -35,8 +35,9 @@
 	 (img (car (gimp-image-new width height RGB)))
 	 (layer-one (car (gimp-layer-new img width height
 					 RGB-IMAGE "Bottom" 100 NORMAL-MODE)))
+     (layer-two)
 	)
-  (gimp-gradients-set-gradient gradient)
+  (gimp-context-set-gradient gradient)
   (gimp-image-undo-disable img)
   (gimp-image-add-layer img layer-one 0)
 
