@@ -27,26 +27,26 @@
 	 (bg-layer (car (gimp-layer-new img width height  RGB-IMAGE "Background" 100 NORMAL-MODE)))
 	 (text-layer (car (gimp-layer-new img width height  RGBA-IMAGE "Text layer" 100 NORMAL-MODE)))
 	 (text-mask 0)
-	 (grey (/ (* density 255) 100))
-	 (old-fg (car (gimp-palette-get-foreground)))
-	 (old-bg (car (gimp-palette-get-background))))
+	 (grey (/ (* density 255) 100)))
+
+    (gimp-context-push)
 
     (gimp-image-undo-disable img)
     (gimp-image-add-layer img bg-layer 1)
     (gimp-image-add-layer img text-layer -1)
 
-    (gimp-palette-set-background bg-color)
+    (gimp-context-set-background bg-color)
     (gimp-edit-clear bg-layer)
     (gimp-edit-clear text-layer)
 
-    (gimp-palette-set-foreground text-color)
+    (gimp-context-set-foreground text-color)
     (gimp-floating-sel-anchor (car (gimp-text-fontname img text-layer (/ (+ 20 blur-radius) 2) (/ (+ 20 blur-radius) 2) string 0 TRUE font-size PIXELS font)))
 
     (set! text-mask (car (gimp-layer-create-mask text-layer ADD-ALPHA-MASK)))
     (gimp-layer-add-mask text-layer text-mask)
 
     (gimp-selection-layer-alpha text-layer)
-    (gimp-palette-set-background (list grey grey grey))
+    (gimp-context-set-background (list grey grey grey))
     (gimp-edit-fill text-mask BACKGROUND-FILL)
     (gimp-selection-clear img)
     (if (> blur-radius 0)
@@ -58,11 +58,10 @@
     (gimp-edit-fill text-layer FOREGROUND-FILL)
     (gimp-layer-remove-mask text-layer MASK-APPLY)
 
-    (gimp-palette-set-foreground old-fg)
-    (gimp-palette-set-background old-bg)
-
     (gimp-image-undo-enable img)
-    (gimp-display-new img)))
+    (gimp-display-new img)
+
+    (gimp-context-pop)))
 
 (script-fu-register "script-fu-newsprint-text"
 	    _"<Toolbox>/Xtns/Script-Fu/Logos/Newsprint Text..."
