@@ -34,7 +34,16 @@
   (let* (
 	 (type (car (gimp-drawable-type-with-alpha drawable)))
 	 (image-width (car (gimp-image-width image)))
-	 (image-height (car (gimp-image-height image))))
+	 (image-height (car (gimp-image-height image)))
+     (active-selection)
+     (from-selection)
+     (selection-bounds)
+     (select-offset-x)
+     (select-offset-y)
+     (select-width)
+     (select-height)
+     (effect-layer)
+     (active-layer))
     
     (gimp-image-undo-group-start image)
     (gimp-layer-add-alpha drawable)
@@ -75,8 +84,10 @@
 	  (let ((floating-sel (car (gimp-edit-paste effect-layer FALSE))))
 	    (gimp-floating-sel-anchor floating-sel)
 	    )
-	  (gimp-image-set-active-layer image effect-layer )))
-    (set! active-layer (car (gimp-image-get-active-layer image)))
+      (gimp-image-set-active-layer image effect-layer ))
+      (set! effect-layer drawable)
+    )
+    (set! active-layer effect-layer)
 
     ; all the fun stuff goes here
     (if (= pixelize TRUE)
