@@ -24,16 +24,15 @@
 
 
 (define (script-fu-selection-to-image image drawable)
-  (let* (
-	 (draw-type (car (gimp-drawable-type-with-alpha drawable)))
+  (let* ((draw-type (car (gimp-drawable-type-with-alpha drawable)))
 	 (image-type (car (gimp-image-base-type image)))
-	 (old-bg (car (gimp-palette-get-background))))
+	 (selection-bounds (gimp-selection-bounds image))
+	 (select-offset-x  (cadr selection-bounds))
+	 (select-offset-y  (caddr selection-bounds))
+	 (selection-width  (- (cadr (cddr selection-bounds)) select-offset-x))
+	 (selection-height (- (caddr (cddr selection-bounds)) select-offset-y)))
 
-    (set! selection-bounds (gimp-selection-bounds image))
-    (set! select-offset-x (cadr selection-bounds))
-    (set! select-offset-y (caddr selection-bounds))
-    (set! selection-width (- (cadr (cddr selection-bounds)) select-offset-x))
-    (set! selection-height (- (caddr (cddr selection-bounds)) select-offset-y))
+    (gimp-context-push)
 
     (gimp-image-undo-disable image)
     
@@ -48,20 +47,23 @@
 
     (gimp-edit-copy drawable)
 
-    (set! new-image (car (gimp-image-new selection-width selection-height image-type)))
-    (set! new-draw (car (gimp-layer-new new-image selection-width selection-height draw-type "Selection" 100 NORMAL-MODE)))
+    (set! new-image (car (gimp-image-new selection-width
+					 selection-height image-type)))
+    (set! new-draw (car (gimp-layer-new new-image
+					selection-width selection-height
+					draw-type "Selection" 100 NORMAL-MODE)))
     (gimp-image-add-layer new-image new-draw 0)
     (gimp-drawable-fill new-draw BACKGROUND-FILL)
 
     (let ((floating-sel (car (gimp-edit-paste new-draw FALSE))))
-      (gimp-floating-sel-anchor floating-sel)
-      )
+      (gimp-floating-sel-anchor floating-sel))
 
-    (gimp-palette-set-background old-bg)
     (gimp-image-undo-enable image)
     (gimp-image-set-active-layer image drawable)
     (gimp-display-new new-image)
-    (gimp-displays-flush)))
+    (gimp-displays-flush)
+
+    (gimp-context-pop)))
 
 (script-fu-register "script-fu-selection-to-image"
 		    _"<Image>/Script-Fu/Selection/To _Image"
