@@ -116,12 +116,6 @@
          (cx 0)                         ; Current x,y
          (cy 0)
 
-         ; Save old foreground color, brush, opacity and paint mode
-         (old-fg-color (car (gimp-palette-get-foreground)))
-         (old-brush (car (gimp-brushes-get-brush)))
-         (old-opacity (car (gimp-brushes-get-opacity)))
-         (old-paint-mode (car (gimp-brushes-get-paint-mode)))
-
          ; If its a polygon or frame, how many sides does it have.
          (poly (if (= shape 1) 4   ; A frame has four sides.
                               (if (> shape 1) (+ shape 1) 0)))
@@ -242,13 +236,15 @@
  ;; Execution starts here.
  ;;
 
+    (gimp-context-push)
+
     (gimp-image-undo-group-start img)
 
     ; Set new color, brush, opacity, paint mode.
-    (gimp-palette-set-foreground color)
-    (gimp-brushes-set-brush (car brush))
-    (gimp-brushes-set-opacity (* 100 (car (cdr brush))))
-    (gimp-brushes-set-paint-mode (car (cdr (cdr (cdr brush)))))
+    (gimp-context-set-foreground color)
+    (gimp-context-set-brush (car brush))
+    (gimp-context-set-opacity (* 100 (car (cdr brush))))
+    (gimp-context-set-paint-mode (car (cdr (cdr (cdr brush)))))
 
     (while (< index steps)
 
@@ -262,14 +258,14 @@
         (if (< 0 color-method)  ; use gradient.
            (if (< (/ (+ grad-index 4) gradn) (/ index steps))
              (begin
-              (gimp-palette-set-foreground 
+              (gimp-context-set-foreground 
                 (list 
                   (* 255 (aref grada grad-index))
                   (* 255 (aref grada (+ 1 grad-index)) )
                   (* 255 (aref grada (+ 2 grad-index)) )
                 )
               )
-              (gimp-brushes-set-opacity (* 100 (aref grada (+ 3 grad-index) ) )  )
+              (gimp-context-set-opacity (* 100 (aref grada (+ 3 grad-index) ) )  )
               (set! grad-index (+ 4 grad-index))
 
               ; Draw points
@@ -285,16 +281,10 @@
     ; Draw remaining points.
     (flush-points point-index)   
 
-    ; Restore foreground color, brush and opacity
-    (gimp-palette-set-foreground old-fg-color)
-    (gimp-brushes-set-brush old-brush)
-    (gimp-brushes-set-opacity old-opacity)
-    (gimp-brushes-set-paint-mode old-paint-mode)
-
     (gimp-image-undo-group-end img)
     (gimp-displays-flush)
-  )
-)
+
+    (gimp-context-pop)))
 
 
 ; This routine is invoked by a dialog.
