@@ -59,10 +59,9 @@
 	 (bg-layer (car (gimp-layer-new img width height RGB-IMAGE "Background" 100 NORMAL-MODE)))
 	 (glow-layer (car (gimp-layer-new img width height RGBA-IMAGE "Glow" 100 NORMAL-MODE)))
 	 (shadow-layer (car (gimp-layer-new img width height RGBA-IMAGE "Drop Shadow" 100 NORMAL-MODE)))
-	 (bump-channel (car (gimp-channel-new img width height "Bump Map" 50 '(0 0 0))))
-	 (old-pattern (car (gimp-patterns-get-pattern)))
-	 (old-fg (car (gimp-palette-get-foreground)))
-	 (old-bg (car (gimp-palette-get-background))))
+	 (bump-channel (car (gimp-channel-new img width height "Bump Map" 50 '(0 0 0)))))
+
+    (gimp-context-push)
 
     (gimp-selection-none img)
     (script-fu-util-image-resize-from-layer img logo-layer)
@@ -72,7 +71,7 @@
     (gimp-image-add-channel img bump-channel 0)
     (gimp-layer-set-preserve-trans logo-layer TRUE)
 
-    (gimp-palette-set-background '(0 0 0))
+    (gimp-context-set-background '(0 0 0))
     (gimp-edit-fill bg-layer BACKGROUND-FILL)
     (gimp-edit-clear shadow-layer)
     (gimp-edit-clear glow-layer)
@@ -80,19 +79,19 @@
     (gimp-selection-layer-alpha logo-layer)
     (gimp-selection-grow img grow)
     (gimp-selection-feather img feather)
-    (gimp-palette-set-background glow-color)
+    (gimp-context-set-background glow-color)
     (gimp-selection-feather img feather)
     (gimp-edit-fill glow-layer BACKGROUND-FILL)
 
     (gimp-selection-layer-alpha logo-layer)
     (gimp-selection-feather img shadow-feather)
-    (gimp-palette-set-background '(0 0 0))
+    (gimp-context-set-background '(0 0 0))
     (gimp-selection-translate img offx offy)
     (gimp-edit-fill shadow-layer BACKGROUND-FILL)
 
     (gimp-selection-none img)
-    (gimp-palette-set-background '(31 31 31))
-    (gimp-palette-set-foreground '(255 255 255))
+    (gimp-context-set-background '(31 31 31))
+    (gimp-context-set-foreground '(255 255 255))
 
     (gimp-edit-blend logo-layer FG-BG-RGB-MODE NORMAL-MODE
 		     GRADIENT-BILINEAR 100 0 REPEAT-NONE FALSE
@@ -102,16 +101,15 @@
     (plug-in-nova 1 img glow-layer novax novay glow-color novaradius 100 0)
 
     (gimp-selection-all img)
-    (gimp-patterns-set-pattern "Stone")
+    (gimp-context-set-pattern "Stone")
     (gimp-edit-bucket-fill bump-channel PATTERN-BUCKET-FILL NORMAL-MODE 100 0 FALSE 0 0)
     (plug-in-bump-map 1 img logo-layer bump-channel
 		      135.0 45.0 4 0 0 0 0 FALSE FALSE 0)
     (gimp-image-remove-channel img bump-channel)
     (gimp-selection-none img)
 
-    (gimp-patterns-set-pattern old-pattern)
-    (gimp-palette-set-background old-bg)
-    (gimp-palette-set-foreground old-fg)))
+    (gimp-context-pop)))
+
 
 (define (script-fu-starscape-logo-alpha img
 					logo-layer
