@@ -32,20 +32,17 @@
 	 (img (car (gimp-image-new img-size img-size RGB)))
 	 (drawable (car (gimp-layer-new img img-size img-size
 					RGB-IMAGE "Swirly pattern"
-					100 NORMAL-MODE)))
+					100 NORMAL-MODE))))
 
-	 ; Save old foregound and background colors
-
-	 (old-fg-color (car (gimp-palette-get-foreground)))
-	 (old-bg-color (car (gimp-palette-get-background))))
+    (gimp-context-push)
 
     (gimp-image-undo-disable img)
     (gimp-image-add-layer img drawable 0)
 
     ; Render checkerboard
 
-    (gimp-palette-set-foreground '(0 0 0))
-    (gimp-palette-set-background '(255 255 255))
+    (gimp-context-set-foreground '(0 0 0))
+    (gimp-context-set-background '(255 255 255))
 
     (plug-in-checkerboard 1 img drawable 0 qsize)
 
@@ -74,10 +71,10 @@
     ; Terminate
 
     (gimp-selection-none img)
-    (gimp-palette-set-foreground old-fg-color)
-    (gimp-palette-set-background old-bg-color)
     (gimp-image-undo-enable img)
-    (gimp-display-new img)))
+    (gimp-display-new img)
+
+    (gimp-context-pop)))
 
 (script-fu-register "script-fu-swirly-pattern"
 		    _"<Toolbox>/Xtns/Script-Fu/Patterns/_Swirly..."
