@@ -51,13 +51,13 @@
     (gimp-image-undo-disable img)
     (gimp-image-add-layer img drawable 0)
 
-    (gimp-palette-set-background '(0 0 0))
+    (gimp-context-set-background '(0 0 0))
     (gimp-edit-fill drawable BACKGROUND-FILL)
 
     ; Create main horizontal ribbon
 
-    (gimp-palette-set-foreground '(255 255 255))
-    (gimp-palette-set-background (list darkness darkness darkness))
+    (gimp-context-set-foreground '(255 255 255))
+    (gimp-context-set-background (list darkness darkness darkness))
 
     (gimp-rect-select img
 		      0
@@ -174,14 +174,14 @@
     (gimp-image-undo-disable img)
     (gimp-image-add-layer img drawable 0)
 
-    (gimp-palette-set-background '(0 0 0))
+    (gimp-context-set-background '(0 0 0))
     (gimp-edit-fill drawable BACKGROUND-FILL)
 
     (gimp-rect-select img r1-x1 r1-y1 r1-width r1-height CHANNEL-OP-REPLACE FALSE 0)
     (gimp-rect-select img r2-x1 r2-y1 r2-width r2-height CHANNEL-OP-ADD FALSE 0)
     (gimp-rect-select img r3-x1 r3-y1 r3-width r3-height CHANNEL-OP-ADD FALSE 0)
 
-    (gimp-palette-set-background '(255 255 255))
+    (gimp-context-set-background '(255 255 255))
     (gimp-edit-fill drawable BACKGROUND-FILL)
     (gimp-selection-none img)
 
@@ -276,7 +276,7 @@
 					"Threads" 100 NORMAL-MODE)))
 	 (dense (/ density 100.0)))
     (gimp-image-add-layer img drawable -1)
-    (gimp-palette-set-background '(255 255 255))
+    (gimp-context-set-background '(255 255 255))
     (gimp-edit-fill drawable BACKGROUND-FILL)
     (plug-in-noisify 1 img drawable FALSE dense dense dense dense)
     (plug-in-c-astretch 1 img drawable)
@@ -351,10 +351,7 @@
 			 thread-length
 			 thread-density
 			 thread-intensity)
-  (let* ((old-fg-color (car (gimp-palette-get-foreground)))
-	 (old-bg-color (car (gimp-palette-get-background)))
-
-	 (d-img (car (gimp-drawable-get-image drawable)))
+  (let* ((d-img (car (gimp-drawable-get-image drawable)))
 	 (d-width (car (gimp-drawable-width drawable)))
 	 (d-height (car (gimp-drawable-height drawable)))
 	 (d-offsets (gimp-drawable-offsets drawable))
@@ -371,6 +368,8 @@
 	 (w-img (car weaving))
 	 (w-layer (cadr weaving)))
 
+    (gimp-context-push)
+
     (gimp-selection-all w-img)
     (gimp-edit-copy w-layer)
     (gimp-image-delete w-img)
@@ -381,9 +380,9 @@
       (gimp-layer-set-mode floating-sel MULTIPLY-MODE)
       (gimp-floating-sel-to-layer floating-sel))
 
-    (gimp-palette-set-foreground old-fg-color)
-    (gimp-palette-set-background old-bg-color)
-    (gimp-displays-flush)))
+    (gimp-displays-flush)
+
+    (gimp-context-pop)))
 
 (script-fu-register "script-fu-weave"
 		    _"<Image>/Script-Fu/Alchemy/_Weave..."
